Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Addon

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Addon resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Addon

Returns a new instance of GoogleCloudApihubV1Addon.



194
195
196
# File 'lib/google/apis/apihub_v1/classes.rb', line 194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::ApihubV1::GoogleCloudApihubV1AddonConfig

Configuration for the addon. Corresponds to the JSON property config



155
156
157
# File 'lib/google/apis/apihub_v1/classes.rb', line 155

def config
  @config
end

#create_timeString

Output only. The time at which the addon was created. Corresponds to the JSON property createTime

Returns:

  • (String)


160
161
162
# File 'lib/google/apis/apihub_v1/classes.rb', line 160

def create_time
  @create_time
end

#data_sourceString

Required. The data source on which the addon operates. This determines which field in the config oneof is used. Corresponds to the JSON property dataSource

Returns:

  • (String)


166
167
168
# File 'lib/google/apis/apihub_v1/classes.rb', line 166

def data_source
  @data_source
end

#descriptionString

Optional. The description of the addon. Corresponds to the JSON property description

Returns:

  • (String)


171
172
173
# File 'lib/google/apis/apihub_v1/classes.rb', line 171

def description
  @description
end

#display_nameString

Required. The display name of the addon. Corresponds to the JSON property displayName

Returns:

  • (String)


176
177
178
# File 'lib/google/apis/apihub_v1/classes.rb', line 176

def display_name
  @display_name
end

#nameString

Identifier. The name of the addon to enable. Format: projects/project/ locations/location/addons/addon`. Corresponds to the JSON propertyname`

Returns:

  • (String)


182
183
184
# File 'lib/google/apis/apihub_v1/classes.rb', line 182

def name
  @name
end

#stateString

Output only. The state of the addon. Corresponds to the JSON property state

Returns:

  • (String)


187
188
189
# File 'lib/google/apis/apihub_v1/classes.rb', line 187

def state
  @state
end

#update_timeString

Output only. The time at which the addon was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


192
193
194
# File 'lib/google/apis/apihub_v1/classes.rb', line 192

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



199
200
201
202
203
204
205
206
207
208
# File 'lib/google/apis/apihub_v1/classes.rb', line 199

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end