Class: Google::Apis::ApihubV1::GoogleCloudApihubV1AllDataAddonConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Configuration for addons which act on all data in the API hub. This is used to specify if the addon is enabled for all data in the API hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1AllDataAddonConfig

Returns a new instance of GoogleCloudApihubV1AllDataAddonConfig.



270
271
272
# File 'lib/google/apis/apihub_v1/classes.rb', line 270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Required. If true, the addon is enabled for all data in the API hub. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


267
268
269
# File 'lib/google/apis/apihub_v1/classes.rb', line 267

def enabled
  @enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



275
276
277
# File 'lib/google/apis/apihub_v1/classes.rb', line 275

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
end