Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Api

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An API resource in the API Hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Api

Returns a new instance of GoogleCloudApihubV1Api.



441
442
443
# File 'lib/google/apis/apihub_v1/classes.rb', line 441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_functional_requirementsGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property apiFunctionalRequirements



332
333
334
# File 'lib/google/apis/apihub_v1/classes.rb', line 332

def api_functional_requirements
  @api_functional_requirements
end

#api_requirementsGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property apiRequirements



337
338
339
# File 'lib/google/apis/apihub_v1/classes.rb', line 337

def api_requirements
  @api_requirements
end

#api_styleGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property apiStyle



342
343
344
# File 'lib/google/apis/apihub_v1/classes.rb', line 342

def api_style
  @api_style
end

#api_technical_requirementsGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property apiTechnicalRequirements



347
348
349
# File 'lib/google/apis/apihub_v1/classes.rb', line 347

def api_technical_requirements
  @api_technical_requirements
end

#attributesHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>

Optional. The list of user defined attributes associated with the API resource. The key is the attribute name. It will be of the format: projects/project/ locations/location/attributes/attribute`. The value is the attribute values associated with the resource. Corresponds to the JSON propertyattributes`



355
356
357
# File 'lib/google/apis/apihub_v1/classes.rb', line 355

def attributes
  @attributes
end

#business_unitGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property businessUnit



360
361
362
# File 'lib/google/apis/apihub_v1/classes.rb', line 360

def business_unit
  @business_unit
end

#create_timeString

Output only. The time at which the API resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


365
366
367
# File 'lib/google/apis/apihub_v1/classes.rb', line 365

def create_time
  @create_time
end

#descriptionString

Optional. The description of the API resource. Corresponds to the JSON property description

Returns:

  • (String)


370
371
372
# File 'lib/google/apis/apihub_v1/classes.rb', line 370

def description
  @description
end

#display_nameString

Required. The display name of the API resource. Corresponds to the JSON property displayName

Returns:

  • (String)


375
376
377
# File 'lib/google/apis/apihub_v1/classes.rb', line 375

def display_name
  @display_name
end

#documentationGoogle::Apis::ApihubV1::GoogleCloudApihubV1Documentation

Documentation details. Corresponds to the JSON property documentation



380
381
382
# File 'lib/google/apis/apihub_v1/classes.rb', line 380

def documentation
  @documentation
end

#fingerprintString

Optional. Fingerprint of the API resource. This must be unique for each API resource. It can neither be unset nor be updated to an existing fingerprint of another API resource. Corresponds to the JSON property fingerprint

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/apihub_v1/classes.rb', line 387

def fingerprint
  @fingerprint
end

#maturity_levelGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property maturityLevel



392
393
394
# File 'lib/google/apis/apihub_v1/classes.rb', line 392

def maturity_level
  @maturity_level
end

#nameString

Identifier. The name of the API resource in the API Hub. Format: projects/ project/locations/location/apis/api` Corresponds to the JSON propertyname`

Returns:

  • (String)


398
399
400
# File 'lib/google/apis/apihub_v1/classes.rb', line 398

def name
  @name
end

#ownerGoogle::Apis::ApihubV1::GoogleCloudApihubV1Owner

Owner details. Corresponds to the JSON property owner



403
404
405
# File 'lib/google/apis/apihub_v1/classes.rb', line 403

def owner
  @owner
end

#selected_versionString

Optional. The selected version for an API resource. This can be used when special handling is needed on client side for particular version of the API. Format is projects/project/locations/location/apis/api/versions/ version` Corresponds to the JSON propertyselectedVersion`

Returns:

  • (String)


411
412
413
# File 'lib/google/apis/apihub_v1/classes.rb', line 411

def selected_version
  @selected_version
end

#source_metadataArray<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>

Output only. The list of sources and metadata from the sources of the API resource. Corresponds to the JSON property sourceMetadata



417
418
419
# File 'lib/google/apis/apihub_v1/classes.rb', line 417

def 
  @source_metadata
end

#target_userGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property targetUser



422
423
424
# File 'lib/google/apis/apihub_v1/classes.rb', line 422

def target_user
  @target_user
end

#teamGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property team



427
428
429
# File 'lib/google/apis/apihub_v1/classes.rb', line 427

def team
  @team
end

#update_timeString

Output only. The time at which the API resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


432
433
434
# File 'lib/google/apis/apihub_v1/classes.rb', line 432

def update_time
  @update_time
end

#versionsArray<String>

Output only. The list of versions present in an API resource. Note: An API resource can be associated with more than 1 version. Format is projects/ project/locations/location/apis/api/versions/version` Corresponds to the JSON propertyversions`

Returns:

  • (Array<String>)


439
440
441
# File 'lib/google/apis/apihub_v1/classes.rb', line 439

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/google/apis/apihub_v1/classes.rb', line 446

def update!(**args)
  @api_functional_requirements = args[:api_functional_requirements] if args.key?(:api_functional_requirements)
  @api_requirements = args[:api_requirements] if args.key?(:api_requirements)
  @api_style = args[:api_style] if args.key?(:api_style)
  @api_technical_requirements = args[:api_technical_requirements] if args.key?(:api_technical_requirements)
  @attributes = args[:attributes] if args.key?(:attributes)
  @business_unit = args[:business_unit] if args.key?(:business_unit)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @maturity_level = args[:maturity_level] if args.key?(:maturity_level)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @selected_version = args[:selected_version] if args.key?(:selected_version)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @target_user = args[:target_user] if args.key?(:target_user)
  @team = args[:team] if args.key?(:team)
  @update_time = args[:update_time] if args.key?(:update_time)
  @versions = args[:versions] if args.key?(:versions)
end