Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApiHubInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An ApiHubInstance represents the instance resources of the API Hub. Currently, only one ApiHub instance is allowed for each project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ApiHubInstance

Returns a new instance of GoogleCloudApihubV1ApiHubInstance.



538
539
540
# File 'lib/google/apis/apihub_v1/classes.rb', line 538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::ApihubV1::GoogleCloudApihubV1Config

Available configurations to provision an ApiHub Instance. Corresponds to the JSON property config



497
498
499
# File 'lib/google/apis/apihub_v1/classes.rb', line 497

def config
  @config
end

#create_timeString

Output only. Creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


502
503
504
# File 'lib/google/apis/apihub_v1/classes.rb', line 502

def create_time
  @create_time
end

#descriptionString

Optional. Description of the ApiHub instance. Corresponds to the JSON property description

Returns:

  • (String)


507
508
509
# File 'lib/google/apis/apihub_v1/classes.rb', line 507

def description
  @description
end

#labelsHash<String,String>

Optional. Instance labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/ docs/labeling-resources Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


514
515
516
# File 'lib/google/apis/apihub_v1/classes.rb', line 514

def labels
  @labels
end

#nameString

Identifier. Format: projects/project/locations/location/apiHubInstances/ apiHubInstance`. Corresponds to the JSON propertyname`

Returns:

  • (String)


520
521
522
# File 'lib/google/apis/apihub_v1/classes.rb', line 520

def name
  @name
end

#stateString

Output only. The current state of the ApiHub instance. Corresponds to the JSON property state

Returns:

  • (String)


525
526
527
# File 'lib/google/apis/apihub_v1/classes.rb', line 525

def state
  @state
end

#state_messageString

Output only. Extra information about ApiHub instance state. Currently the message would be populated when state is FAILED. Corresponds to the JSON property stateMessage

Returns:

  • (String)


531
532
533
# File 'lib/google/apis/apihub_v1/classes.rb', line 531

def state_message
  @state_message
end

#update_timeString

Output only. Last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


536
537
538
# File 'lib/google/apis/apihub_v1/classes.rb', line 536

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



543
544
545
546
547
548
549
550
551
552
# File 'lib/google/apis/apihub_v1/classes.rb', line 543

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_message = args[:state_message] if args.key?(:state_message)
  @update_time = args[:update_time] if args.key?(:update_time)
end