Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApiHubResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

ApiHubResource is one of the resources such as Api, Operation, Deployment, Definition, Spec and Version resources stored in API-Hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ApiHubResource

Returns a new instance of GoogleCloudApihubV1ApiHubResource.



608
609
610
# File 'lib/google/apis/apihub_v1/classes.rb', line 608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiGoogle::Apis::ApihubV1::GoogleCloudApihubV1Api

An API resource in the API Hub. Corresponds to the JSON property api



563
564
565
# File 'lib/google/apis/apihub_v1/classes.rb', line 563

def api
  @api
end

#definitionGoogle::Apis::ApihubV1::GoogleCloudApihubV1Definition

Represents a definition for example schema, request, response definitions contained in an API version. A definition is added/updated/deleted in an API version when a new spec is added or an existing spec is updated/deleted in a version. Currently, definition will be created only corresponding to OpenAPI spec as parsing is supported for OpenAPI spec. Also, within OpenAPI spec, only schema object is supported. Corresponds to the JSON property definition



573
574
575
# File 'lib/google/apis/apihub_v1/classes.rb', line 573

def definition
  @definition
end

#deploymentGoogle::Apis::ApihubV1::GoogleCloudApihubV1Deployment

Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API. Corresponds to the JSON property deployment



581
582
583
# File 'lib/google/apis/apihub_v1/classes.rb', line 581

def deployment
  @deployment
end

#operationGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApiOperation

Represents an operation contained in an API version in the API Hub. An operation is added/updated/deleted in an API version when a new spec is added or an existing spec is updated/deleted in a version. Currently, an operation will be created only corresponding to OpenAPI spec as parsing is supported for OpenAPI spec. Alternatively operations can be managed via create,update and delete APIs, creation of apiOperation can be possible only for version with no parsed operations and update/delete can be possible only for operations created via create API. Corresponds to the JSON property operation



593
594
595
# File 'lib/google/apis/apihub_v1/classes.rb', line 593

def operation
  @operation
end

#specGoogle::Apis::ApihubV1::GoogleCloudApihubV1Spec

Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently. Corresponds to the JSON property spec



600
601
602
# File 'lib/google/apis/apihub_v1/classes.rb', line 600

def spec
  @spec
end

#versionGoogle::Apis::ApihubV1::GoogleCloudApihubV1Version

Represents a version of the API resource in API hub. This is also referred to as the API version. Corresponds to the JSON property version



606
607
608
# File 'lib/google/apis/apihub_v1/classes.rb', line 606

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



613
614
615
616
617
618
619
620
# File 'lib/google/apis/apihub_v1/classes.rb', line 613

def update!(**args)
  @api = args[:api] if args.key?(:api)
  @definition = args[:definition] if args.key?(:definition)
  @deployment = args[:deployment] if args.key?(:deployment)
  @operation = args[:operation] if args.key?(:operation)
  @spec = args[:spec] if args.key?(:spec)
  @version = args[:version] if args.key?(:version)
end