Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApiView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The view of an API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ApiView

Returns a new instance of GoogleCloudApihubV1ApiView.



760
761
762
# File 'lib/google/apis/apihub_v1/classes.rb', line 760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_server_viewGoogle::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionDeploymentView

A flattened view of an API, its version and one of the linked deployments. Corresponds to the JSON property mcpServerView



751
752
753
# File 'lib/google/apis/apihub_v1/classes.rb', line 751

def mcp_server_view
  @mcp_server_view
end

#mcp_tool_viewGoogle::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView

A flattened view of an API, its version, one of its operations and one of the linked deployments. If there are no deployments linked to the operation then the result will be empty. Corresponds to the JSON property mcpToolView



758
759
760
# File 'lib/google/apis/apihub_v1/classes.rb', line 758

def mcp_tool_view
  @mcp_tool_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



765
766
767
768
# File 'lib/google/apis/apihub_v1/classes.rb', line 765

def update!(**args)
  @mcp_server_view = args[:mcp_server_view] if args.key?(:mcp_server_view)
  @mcp_tool_view = args[:mcp_tool_view] if args.key?(:mcp_tool_view)
end