Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXHybridConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Configuration for Apigee X and Apigee Hybrid gateways. Applicability of a filter is determined by the filter being provided. If none of the filters are provided the addon will be enabled for all data brought in by the gateway plugin instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ApigeeXHybridConfig

Returns a new instance of GoogleCloudApihubV1ApigeeXHybridConfig.



827
828
829
# File 'lib/google/apis/apihub_v1/classes.rb', line 827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environment_filterGoogle::Apis::ApihubV1::GoogleCloudApihubV1EnvironmentFilter

Filter for environments. Corresponds to the JSON property environmentFilter



825
826
827
# File 'lib/google/apis/apihub_v1/classes.rb', line 825

def environment_filter
  @environment_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



832
833
834
# File 'lib/google/apis/apihub_v1/classes.rb', line 832

def update!(**args)
  @environment_filter = args[:environment_filter] if args.key?(:environment_filter)
end