Class: Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The attribute values associated with resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1AttributeValues

Returns a new instance of GoogleCloudApihubV1AttributeValues.



1037
1038
1039
# File 'lib/google/apis/apihub_v1/classes.rb', line 1037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributeString

Output only. The name of the attribute. Format: projects/project/locations/ location/attributes/attribute Corresponds to the JSON property attribute

Returns:

  • (String)


1015
1016
1017
# File 'lib/google/apis/apihub_v1/classes.rb', line 1015

def attribute
  @attribute
end

#enum_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1EnumAttributeValues

The attribute values of data type enum. Corresponds to the JSON property enumValues



1020
1021
1022
# File 'lib/google/apis/apihub_v1/classes.rb', line 1020

def enum_values
  @enum_values
end

#json_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues

The attribute values of data type string or JSON. Corresponds to the JSON property jsonValues



1025
1026
1027
# File 'lib/google/apis/apihub_v1/classes.rb', line 1025

def json_values
  @json_values
end

#string_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues

The attribute values of data type string or JSON. Corresponds to the JSON property stringValues



1030
1031
1032
# File 'lib/google/apis/apihub_v1/classes.rb', line 1030

def string_values
  @string_values
end

#uri_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues

The attribute values of data type string or JSON. Corresponds to the JSON property uriValues



1035
1036
1037
# File 'lib/google/apis/apihub_v1/classes.rb', line 1035

def uri_values
  @uri_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1042
1043
1044
1045
1046
1047
1048
# File 'lib/google/apis/apihub_v1/classes.rb', line 1042

def update!(**args)
  @attribute = args[:attribute] if args.key?(:attribute)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @json_values = args[:json_values] if args.key?(:json_values)
  @string_values = args[:string_values] if args.key?(:string_values)
  @uri_values = args[:uri_values] if args.key?(:uri_values)
end