Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

ConfigVariable represents a additional configuration variable present in a PluginInstance Config or AuthConfig, based on a ConfigVariableTemplate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ConfigVariable

Returns a new instance of GoogleCloudApihubV1ConfigVariable.



1320
1321
1322
# File 'lib/google/apis/apihub_v1/classes.rb', line 1320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valueBoolean Also known as: bool_value?

Optional. The config variable value in case of config variable of type boolean. Corresponds to the JSON property boolValue

Returns:

  • (Boolean)


1276
1277
1278
# File 'lib/google/apis/apihub_v1/classes.rb', line 1276

def bool_value
  @bool_value
end

#enum_valueGoogle::Apis::ApihubV1::GoogleCloudApihubV1ConfigValueOption

ConfigValueOption represents an option for a config variable of type enum or multi select. Corresponds to the JSON property enumValue



1283
1284
1285
# File 'lib/google/apis/apihub_v1/classes.rb', line 1283

def enum_value
  @enum_value
end

#int_valueFixnum

Optional. The config variable value in case of config variable of type integer. Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


1288
1289
1290
# File 'lib/google/apis/apihub_v1/classes.rb', line 1288

def int_value
  @int_value
end

#keyString

Output only. Key will be the id to uniquely identify the config variable. Corresponds to the JSON property key

Returns:

  • (String)


1293
1294
1295
# File 'lib/google/apis/apihub_v1/classes.rb', line 1293

def key
  @key
end

#multi_int_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1MultiIntValues

The config variable value of data type multi int. Corresponds to the JSON property multiIntValues



1298
1299
1300
# File 'lib/google/apis/apihub_v1/classes.rb', line 1298

def multi_int_values
  @multi_int_values
end

#multi_select_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1MultiSelectValues

The config variable value of data type multi select. Corresponds to the JSON property multiSelectValues



1303
1304
1305
# File 'lib/google/apis/apihub_v1/classes.rb', line 1303

def multi_select_values
  @multi_select_values
end

#multi_string_valuesGoogle::Apis::ApihubV1::GoogleCloudApihubV1MultiStringValues

The config variable value of data type multi string. Corresponds to the JSON property multiStringValues



1308
1309
1310
# File 'lib/google/apis/apihub_v1/classes.rb', line 1308

def multi_string_values
  @multi_string_values
end

#secret_valueGoogle::Apis::ApihubV1::GoogleCloudApihubV1Secret

Secret provides a reference to entries in Secret Manager. Corresponds to the JSON property secretValue



1313
1314
1315
# File 'lib/google/apis/apihub_v1/classes.rb', line 1313

def secret_value
  @secret_value
end

#string_valueString

Optional. The config variable value in case of config variable of type string. Corresponds to the JSON property stringValue

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/apihub_v1/classes.rb', line 1318

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
# File 'lib/google/apis/apihub_v1/classes.rb', line 1325

def update!(**args)
  @bool_value = args[:bool_value] if args.key?(:bool_value)
  @enum_value = args[:enum_value] if args.key?(:enum_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @key = args[:key] if args.key?(:key)
  @multi_int_values = args[:multi_int_values] if args.key?(:multi_int_values)
  @multi_select_values = args[:multi_select_values] if args.key?(:multi_select_values)
  @multi_string_values = args[:multi_string_values] if args.key?(:multi_string_values)
  @secret_value = args[:secret_value] if args.key?(:secret_value)
  @string_value = args[:string_value] if args.key?(:string_value)
end