Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Curation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

A curation resource in the API Hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Curation

Returns a new instance of GoogleCloudApihubV1Curation.



1478
1479
1480
# File 'lib/google/apis/apihub_v1/classes.rb', line 1478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the curation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1424
1425
1426
# File 'lib/google/apis/apihub_v1/classes.rb', line 1424

def create_time
  @create_time
end

#descriptionString

Optional. The description of the curation. Corresponds to the JSON property description

Returns:

  • (String)


1429
1430
1431
# File 'lib/google/apis/apihub_v1/classes.rb', line 1429

def description
  @description
end

#display_nameString

Required. The display name of the curation. Corresponds to the JSON property displayName

Returns:

  • (String)


1434
1435
1436
# File 'lib/google/apis/apihub_v1/classes.rb', line 1434

def display_name
  @display_name
end

#endpointGoogle::Apis::ApihubV1::GoogleCloudApihubV1Endpoint

The endpoint to be triggered for curation. The endpoint will be invoked with a request payload containing ApiMetadata. Response should contain curated data in the form of ApiMetadata. Corresponds to the JSON property endpoint



1441
1442
1443
# File 'lib/google/apis/apihub_v1/classes.rb', line 1441

def endpoint
  @endpoint
end

#last_execution_error_codeString

Output only. The error code of the last execution of the curation. The error code is populated only when the last execution state is failed. Corresponds to the JSON property lastExecutionErrorCode

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/apihub_v1/classes.rb', line 1447

def last_execution_error_code
  @last_execution_error_code
end

#last_execution_error_messageString

Output only. Error message describing the failure, if any, during the last execution of the curation. Corresponds to the JSON property lastExecutionErrorMessage

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/apihub_v1/classes.rb', line 1453

def last_execution_error_message
  @last_execution_error_message
end

#last_execution_stateString

Output only. The last execution state of the curation. Corresponds to the JSON property lastExecutionState

Returns:

  • (String)


1458
1459
1460
# File 'lib/google/apis/apihub_v1/classes.rb', line 1458

def last_execution_state
  @last_execution_state
end

#nameString

Identifier. The name of the curation. Format: projects/project/locations/ location/curations/curation` Corresponds to the JSON propertyname`

Returns:

  • (String)


1464
1465
1466
# File 'lib/google/apis/apihub_v1/classes.rb', line 1464

def name
  @name
end

#plugin_instance_actionsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceActionId>

Output only. The plugin instances and associated actions that are using the curation. Note: A particular curation could be used by multiple plugin instances or multiple actions in a plugin instance. Corresponds to the JSON property pluginInstanceActions



1471
1472
1473
# File 'lib/google/apis/apihub_v1/classes.rb', line 1471

def plugin_instance_actions
  @plugin_instance_actions
end

#update_timeString

Output only. The time at which the curation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1476
1477
1478
# File 'lib/google/apis/apihub_v1/classes.rb', line 1476

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
# File 'lib/google/apis/apihub_v1/classes.rb', line 1483

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @last_execution_error_code = args[:last_execution_error_code] if args.key?(:last_execution_error_code)
  @last_execution_error_message = args[:last_execution_error_message] if args.key?(:last_execution_error_message)
  @last_execution_state = args[:last_execution_state] if args.key?(:last_execution_state)
  @name = args[:name] if args.key?(:name)
  @plugin_instance_actions = args[:plugin_instance_actions] if args.key?(:plugin_instance_actions)
  @update_time = args[:update_time] if args.key?(:update_time)
end