Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Dependency

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

A dependency resource defined in the API hub describes a dependency directed from a consumer to a supplier entity. A dependency can be defined between two Operations or between an Operation and External API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Dependency

Returns a new instance of GoogleCloudApihubV1Dependency.



1672
1673
1674
# File 'lib/google/apis/apihub_v1/classes.rb', line 1672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>

Optional. The list of user defined attributes associated with the dependency resource. The key is the attribute name. It will be of the format: projects/ project/locations/location/attributes/attribute`. The value is the attribute values associated with the resource. Corresponds to the JSON propertyattributes`



1624
1625
1626
# File 'lib/google/apis/apihub_v1/classes.rb', line 1624

def attributes
  @attributes
end

#consumerGoogle::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference

Reference to an entity participating in a dependency. Corresponds to the JSON property consumer



1629
1630
1631
# File 'lib/google/apis/apihub_v1/classes.rb', line 1629

def consumer
  @consumer
end

#create_timeString

Output only. The time at which the dependency was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1634
1635
1636
# File 'lib/google/apis/apihub_v1/classes.rb', line 1634

def create_time
  @create_time
end

#descriptionString

Optional. Human readable description corresponding of the dependency. Corresponds to the JSON property description

Returns:

  • (String)


1639
1640
1641
# File 'lib/google/apis/apihub_v1/classes.rb', line 1639

def description
  @description
end

#discovery_modeString

Output only. Discovery mode of the dependency. Corresponds to the JSON property discoveryMode

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/apihub_v1/classes.rb', line 1644

def discovery_mode
  @discovery_mode
end

#error_detailGoogle::Apis::ApihubV1::GoogleCloudApihubV1DependencyErrorDetail

Details describing error condition of a dependency. Corresponds to the JSON property errorDetail



1649
1650
1651
# File 'lib/google/apis/apihub_v1/classes.rb', line 1649

def error_detail
  @error_detail
end

#nameString

Identifier. The name of the dependency in the API Hub. Format: projects/ project/locations/location/dependencies/dependency` Corresponds to the JSON propertyname`

Returns:

  • (String)


1655
1656
1657
# File 'lib/google/apis/apihub_v1/classes.rb', line 1655

def name
  @name
end

#stateString

Output only. State of the dependency. Corresponds to the JSON property state

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/apihub_v1/classes.rb', line 1660

def state
  @state
end

#supplierGoogle::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference

Reference to an entity participating in a dependency. Corresponds to the JSON property supplier



1665
1666
1667
# File 'lib/google/apis/apihub_v1/classes.rb', line 1665

def supplier
  @supplier
end

#update_timeString

Output only. The time at which the dependency was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/apihub_v1/classes.rb', line 1670

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
# File 'lib/google/apis/apihub_v1/classes.rb', line 1677

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @consumer = args[:consumer] if args.key?(:consumer)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @discovery_mode = args[:discovery_mode] if args.key?(:discovery_mode)
  @error_detail = args[:error_detail] if args.key?(:error_detail)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @supplier = args[:supplier] if args.key?(:supplier)
  @update_time = args[:update_time] if args.key?(:update_time)
end