Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Reference to an entity participating in a dependency.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#external_api_resource_name ⇒ String
The resource name of an external API in the API Hub.
-
#operation_resource_name ⇒ String
The resource name of an operation in the API Hub.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1DependencyEntityReference
constructor
A new instance of GoogleCloudApihubV1DependencyEntityReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1DependencyEntityReference
Returns a new instance of GoogleCloudApihubV1DependencyEntityReference.
1712 1713 1714 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Display name of the entity.
Corresponds to the JSON property displayName
1698 1699 1700 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1698 def display_name @display_name end |
#external_api_resource_name ⇒ String
The resource name of an external API in the API Hub. Format: projects/
project/locations/location/externalApis/external_api`
Corresponds to the JSON propertyexternalApiResourceName`
1704 1705 1706 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1704 def external_api_resource_name @external_api_resource_name end |
#operation_resource_name ⇒ String
The resource name of an operation in the API Hub. Format: projects/project/
locations/location/apis/api/versions/version/operations/operation`
Corresponds to the JSON propertyoperationResourceName`
1710 1711 1712 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1710 def operation_resource_name @operation_resource_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1717 1718 1719 1720 1721 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1717 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @external_api_resource_name = args[:external_api_resource_name] if args.key?(:external_api_resource_name) @operation_resource_name = args[:operation_resource_name] if args.key?(:operation_resource_name) end |