Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

DiscoveredApiOperation represents an API Operation observed in one of the sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiOperation

Returns a new instance of GoogleCloudApihubV1DiscoveredApiOperation.



2124
2125
2126
# File 'lib/google/apis/apihub_v1/classes.rb', line 2124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

Output only. The classification of the discovered API operation. Corresponds to the JSON property classification

Returns:

  • (String)


2072
2073
2074
# File 'lib/google/apis/apihub_v1/classes.rb', line 2072

def classification
  @classification
end

#countFixnum

Optional. The number of occurrences of this API Operation. Corresponds to the JSON property count

Returns:

  • (Fixnum)


2077
2078
2079
# File 'lib/google/apis/apihub_v1/classes.rb', line 2077

def count
  @count
end

#create_timeString

Output only. Create time stamp of the discovered API operation in API Hub. Corresponds to the JSON property createTime

Returns:

  • (String)


2082
2083
2084
# File 'lib/google/apis/apihub_v1/classes.rb', line 2082

def create_time
  @create_time
end

#first_seen_timeString

Optional. First seen time stamp Corresponds to the JSON property firstSeenTime

Returns:

  • (String)


2087
2088
2089
# File 'lib/google/apis/apihub_v1/classes.rb', line 2087

def first_seen_time
  @first_seen_time
end

#http_operationGoogle::Apis::ApihubV1::GoogleCloudApihubV1HttpOperationDetails

An HTTP-based API Operation, sometimes called a "REST" Operation. Corresponds to the JSON property httpOperation



2092
2093
2094
# File 'lib/google/apis/apihub_v1/classes.rb', line 2092

def http_operation
  @http_operation
end

#last_seen_timeString

Optional. Last seen time stamp Corresponds to the JSON property lastSeenTime

Returns:

  • (String)


2097
2098
2099
# File 'lib/google/apis/apihub_v1/classes.rb', line 2097

def last_seen_time
  @last_seen_time
end

#match_resultsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1MatchResult>

Output only. The list of matched results for the discovered API operation. This will be populated only if the classification is known. The current usecase is for a single match. Keeping it repeated to support multiple matches in future. Corresponds to the JSON property matchResults



2105
2106
2107
# File 'lib/google/apis/apihub_v1/classes.rb', line 2105

def match_results
  @match_results
end

#nameString

Identifier. The name of the discovered API Operation. Format: projects/ project/locations/location/discoveredApiObservations/ discovered_api_observation/discoveredApiOperations/discovered_api_operation` Corresponds to the JSON propertyname`

Returns:

  • (String)


2112
2113
2114
# File 'lib/google/apis/apihub_v1/classes.rb', line 2112

def name
  @name
end

#source_metadataGoogle::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata

SourceMetadata represents the metadata for a resource at the source. Corresponds to the JSON property sourceMetadata



2117
2118
2119
# File 'lib/google/apis/apihub_v1/classes.rb', line 2117

def 
  @source_metadata
end

#update_timeString

Output only. Update time stamp of the discovered API operation in API Hub. Corresponds to the JSON property updateTime

Returns:

  • (String)


2122
2123
2124
# File 'lib/google/apis/apihub_v1/classes.rb', line 2122

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/google/apis/apihub_v1/classes.rb', line 2129

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @count = args[:count] if args.key?(:count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @first_seen_time = args[:first_seen_time] if args.key?(:first_seen_time)
  @http_operation = args[:http_operation] if args.key?(:http_operation)
  @last_seen_time = args[:last_seen_time] if args.key?(:last_seen_time)
  @match_results = args[:match_results] if args.key?(:match_results)
  @name = args[:name] if args.key?(:name)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end