Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The endpoint to be triggered for curation. The endpoint will be invoked with a request payload containing ApiMetadata. Response should contain curated data in the form of ApiMetadata.
Instance Attribute Summary collapse
-
#application_integration_endpoint_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApplicationIntegrationEndpointDetails
The details of the Application Integration endpoint to be triggered for curation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Endpoint
constructor
A new instance of GoogleCloudApihubV1Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Endpoint
Returns a new instance of GoogleCloudApihubV1Endpoint.
2206 2207 2208 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_integration_endpoint_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApplicationIntegrationEndpointDetails
The details of the Application Integration endpoint to be triggered for
curation.
Corresponds to the JSON property applicationIntegrationEndpointDetails
2204 2205 2206 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2204 def application_integration_endpoint_details @application_integration_endpoint_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2211 2212 2213 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2211 def update!(**args) @application_integration_endpoint_details = args[:application_integration_endpoint_details] if args.key?(:application_integration_endpoint_details) end |