Class: Google::Apis::ApihubV1::GoogleCloudApihubV1EnvironmentFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Filter for environments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1EnvironmentFilter

Returns a new instance of GoogleCloudApihubV1EnvironmentFilter.



2186
2187
2188
# File 'lib/google/apis/apihub_v1/classes.rb', line 2186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_environmentsBoolean Also known as: all_environments?

Optional. Indicates if this filter should match all environments or only a subset of environments. If set to true, all environments are matched. Corresponds to the JSON property allEnvironments

Returns:

  • (Boolean)


2177
2178
2179
# File 'lib/google/apis/apihub_v1/classes.rb', line 2177

def all_environments
  @all_environments
end

#environmentsArray<String>

Optional. If provided, only environments in this list are matched. This field is ignored if all_environments is true. Corresponds to the JSON property environments

Returns:

  • (Array<String>)


2184
2185
2186
# File 'lib/google/apis/apihub_v1/classes.rb', line 2184

def environments
  @environments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2191
2192
2193
2194
# File 'lib/google/apis/apihub_v1/classes.rb', line 2191

def update!(**args)
  @all_environments = args[:all_environments] if args.key?(:all_environments)
  @environments = args[:environments] if args.key?(:environments)
end