Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The execution status for the plugin instance.
Instance Attribute Summary collapse
-
#current_execution_state ⇒ String
Output only.
-
#last_execution ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
The result of the last execution of the plugin instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ExecutionStatus
constructor
A new instance of GoogleCloudApihubV1ExecutionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ExecutionStatus
Returns a new instance of GoogleCloudApihubV1ExecutionStatus.
2296 2297 2298 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_execution_state ⇒ String
Output only. The current state of the execution.
Corresponds to the JSON property currentExecutionState
2289 2290 2291 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2289 def current_execution_state @current_execution_state end |
#last_execution ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
The result of the last execution of the plugin instance.
Corresponds to the JSON property lastExecution
2294 2295 2296 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2294 def last_execution @last_execution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2301 2302 2303 2304 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2301 def update!(**args) @current_execution_state = args[:current_execution_state] if args.key?(:current_execution_state) @last_execution = args[:last_execution] if args.key?(:last_execution) end |