Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An external API represents an API being provided by external sources. This can be used to model third-party APIs and can be used to define dependencies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ExternalApi

Returns a new instance of GoogleCloudApihubV1ExternalApi.



2363
2364
2365
# File 'lib/google/apis/apihub_v1/classes.rb', line 2363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>

Optional. The list of user defined attributes associated with the Version resource. The key is the attribute name. It will be of the format: projects/ project/locations/location/attributes/attribute`. The value is the attribute values associated with the resource. Corresponds to the JSON propertyattributes`



2318
2319
2320
# File 'lib/google/apis/apihub_v1/classes.rb', line 2318

def attributes
  @attributes
end

#create_timeString

Output only. Creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


2323
2324
2325
# File 'lib/google/apis/apihub_v1/classes.rb', line 2323

def create_time
  @create_time
end

#descriptionString

Optional. Description of the external API. Max length is 2000 characters ( Unicode Code Points). Corresponds to the JSON property description

Returns:

  • (String)


2329
2330
2331
# File 'lib/google/apis/apihub_v1/classes.rb', line 2329

def description
  @description
end

#display_nameString

Required. Display name of the external API. Max length is 63 characters ( Unicode Code Points). Corresponds to the JSON property displayName

Returns:

  • (String)


2335
2336
2337
# File 'lib/google/apis/apihub_v1/classes.rb', line 2335

def display_name
  @display_name
end

#documentationGoogle::Apis::ApihubV1::GoogleCloudApihubV1Documentation

Documentation details. Corresponds to the JSON property documentation



2340
2341
2342
# File 'lib/google/apis/apihub_v1/classes.rb', line 2340

def documentation
  @documentation
end

#endpointsArray<String>

Optional. List of endpoints on which this API is accessible. Corresponds to the JSON property endpoints

Returns:

  • (Array<String>)


2345
2346
2347
# File 'lib/google/apis/apihub_v1/classes.rb', line 2345

def endpoints
  @endpoints
end

#nameString

Identifier. Format: projects/project/locations/location/externalApi/ externalApi`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2351
2352
2353
# File 'lib/google/apis/apihub_v1/classes.rb', line 2351

def name
  @name
end

#pathsArray<String>

Optional. List of paths served by this API. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


2356
2357
2358
# File 'lib/google/apis/apihub_v1/classes.rb', line 2356

def paths
  @paths
end

#update_timeString

Output only. Last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


2361
2362
2363
# File 'lib/google/apis/apihub_v1/classes.rb', line 2361

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/google/apis/apihub_v1/classes.rb', line 2368

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @name = args[:name] if args.key?(:name)
  @paths = args[:paths] if args.key?(:paths)
  @update_time = args[:update_time] if args.key?(:update_time)
end