Class: Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

A flattened view of an API, its version, one of its operations and one of the linked deployments. If there are no deployments linked to the operation then the result will be empty.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView

Returns a new instance of GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView.



2473
2474
2475
# File 'lib/google/apis/apihub_v1/classes.rb', line 2473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiGoogle::Apis::ApihubV1::GoogleCloudApihubV1Api

An API resource in the API Hub. Corresponds to the JSON property api



2445
2446
2447
# File 'lib/google/apis/apihub_v1/classes.rb', line 2445

def api
  @api
end

#api_operationGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApiOperation

Represents an operation contained in an API version in the API Hub. An operation is added/updated/deleted in an API version when a new spec is added or an existing spec is updated/deleted in a version. Currently, an operation will be created only corresponding to OpenAPI spec as parsing is supported for OpenAPI spec. Alternatively operations can be managed via create,update and delete APIs, creation of apiOperation can be possible only for version with no parsed operations and update/delete can be possible only for operations created via create API. Corresponds to the JSON property apiOperation



2457
2458
2459
# File 'lib/google/apis/apihub_v1/classes.rb', line 2457

def api_operation
  @api_operation
end

#deploymentGoogle::Apis::ApihubV1::GoogleCloudApihubV1Deployment

Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API. Corresponds to the JSON property deployment



2465
2466
2467
# File 'lib/google/apis/apihub_v1/classes.rb', line 2465

def deployment
  @deployment
end

#versionGoogle::Apis::ApihubV1::GoogleCloudApihubV1Version

Represents a version of the API resource in API hub. This is also referred to as the API version. Corresponds to the JSON property version



2471
2472
2473
# File 'lib/google/apis/apihub_v1/classes.rb', line 2471

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2478
2479
2480
2481
2482
2483
# File 'lib/google/apis/apihub_v1/classes.rb', line 2478

def update!(**args)
  @api = args[:api] if args.key?(:api)
  @api_operation = args[:api_operation] if args.key?(:api_operation)
  @deployment = args[:deployment] if args.key?(:deployment)
  @version = args[:version] if args.key?(:version)
end