Class: Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginAddonConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginAddonConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Configuration for gateway plugin addons. This is used to specify the list of gateway plugin configs for which the addon is enabled.
Instance Attribute Summary collapse
-
#gateway_plugin_configs ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginConfig>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1GatewayPluginAddonConfig
constructor
A new instance of GoogleCloudApihubV1GatewayPluginAddonConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1GatewayPluginAddonConfig
Returns a new instance of GoogleCloudApihubV1GatewayPluginAddonConfig.
2431 2432 2433 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gateway_plugin_configs ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginConfig>
Required. The list of gateway plugin configs for which the addon is enabled.
Each gateway plugin config should have a unique plugin instance.
Corresponds to the JSON property gatewayPluginConfigs
2429 2430 2431 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2429 def gateway_plugin_configs @gateway_plugin_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2436 2437 2438 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2436 def update!(**args) @gateway_plugin_configs = args[:gateway_plugin_configs] if args.key?(:gateway_plugin_configs) end |