Class: Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Configuration for a gateway plugin. This is used to specify configs for different gateways.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1GatewayPluginConfig

Returns a new instance of GoogleCloudApihubV1GatewayPluginConfig.



2543
2544
2545
# File 'lib/google/apis/apihub_v1/classes.rb', line 2543

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apigee_edge_configGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApigeeEdgeConfig

Configuration for Apigee Edge gateways. Applicability of a filter is determined by the filter being provided. If none of the filters are provided the addon will be enabled for all data brought in by the gateway plugin instance. Corresponds to the JSON property apigeeEdgeConfig



2518
2519
2520
# File 'lib/google/apis/apihub_v1/classes.rb', line 2518

def apigee_edge_config
  @apigee_edge_config
end

#apigee_opdk_configGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApigeeOpdkConfig

Configuration for Apigee OPDK gateways. Applicability of a filter is determined by the filter being provided. If none of the filters are provided the addon will be enabled for all data brought in by the gateway plugin instance. Corresponds to the JSON property apigeeOpdkConfig



2526
2527
2528
# File 'lib/google/apis/apihub_v1/classes.rb', line 2526

def apigee_opdk_config
  @apigee_opdk_config
end

#apigee_x_hybrid_configGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXHybridConfig

Configuration for Apigee X and Apigee Hybrid gateways. Applicability of a filter is determined by the filter being provided. If none of the filters are provided the addon will be enabled for all data brought in by the gateway plugin instance. Corresponds to the JSON property apigeeXHybridConfig



2534
2535
2536
# File 'lib/google/apis/apihub_v1/classes.rb', line 2534

def apigee_x_hybrid_config
  @apigee_x_hybrid_config
end

#plugin_instanceString

Required. The name of the gateway plugin instance for which the config is to be specified. Format: projects/project/locations/location/plugins/plugin/ pluginInstances/plugin_instance Corresponds to the JSON property pluginInstance

Returns:

  • (String)


2541
2542
2543
# File 'lib/google/apis/apihub_v1/classes.rb', line 2541

def plugin_instance
  @plugin_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2548
2549
2550
2551
2552
2553
# File 'lib/google/apis/apihub_v1/classes.rb', line 2548

def update!(**args)
  @apigee_edge_config = args[:apigee_edge_config] if args.key?(:apigee_edge_config)
  @apigee_opdk_config = args[:apigee_opdk_config] if args.key?(:apigee_opdk_config)
  @apigee_x_hybrid_config = args[:apigee_x_hybrid_config] if args.key?(:apigee_x_hybrid_config)
  @plugin_instance = args[:plugin_instance] if args.key?(:plugin_instance)
end