Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HttpOperationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Identifies a single API Hub operation by spec resource name + HTTP path + HTTP method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1HttpOperationConfig

Returns a new instance of GoogleCloudApihubV1HttpOperationConfig.



2720
2721
2722
# File 'lib/google/apis/apihub_v1/classes.rb', line 2720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

Required. HTTP method of the operation within the referenced spec. (GET / PUT / POST / DELETE / OPTIONS / HEAD / PATCH / TRACE). Corresponds to the JSON property method

Returns:

  • (String)


2705
2706
2707
# File 'lib/google/apis/apihub_v1/classes.rb', line 2705

def method_prop
  @method_prop
end

#pathString

Required. HTTP path of the operation within the referenced spec. Match is exact (no template substitution): the path here must appear verbatim on an APIOperationRevision belonging to the spec. Corresponds to the JSON property path

Returns:

  • (String)


2712
2713
2714
# File 'lib/google/apis/apihub_v1/classes.rb', line 2712

def path
  @path
end

#specString

Required. Spec resource name: projects/project/locations/location/apis/ api/versions/version/specs/spec` Corresponds to the JSON propertyspec`

Returns:

  • (String)


2718
2719
2720
# File 'lib/google/apis/apihub_v1/classes.rb', line 2718

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2725
2726
2727
2728
2729
# File 'lib/google/apis/apihub_v1/classes.rb', line 2725

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @path = args[:path] if args.key?(:path)
  @spec = args[:spec] if args.key?(:spec)
end