Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An aggregation of HTTP responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1HttpResponse

Returns a new instance of GoogleCloudApihubV1HttpResponse.



2808
2809
2810
# File 'lib/google/apis/apihub_v1/classes.rb', line 2808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1Header>

Optional. Unordered map from header name to header metadata Corresponds to the JSON property headers



2801
2802
2803
# File 'lib/google/apis/apihub_v1/classes.rb', line 2801

def headers
  @headers
end

#response_codesHash<String,Fixnum>

Optional. Map of status code to observed count Corresponds to the JSON property responseCodes

Returns:

  • (Hash<String,Fixnum>)


2806
2807
2808
# File 'lib/google/apis/apihub_v1/classes.rb', line 2806

def response_codes
  @response_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2813
2814
2815
2816
# File 'lib/google/apis/apihub_v1/classes.rb', line 2813

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @response_codes = args[:response_codes] if args.key?(:response_codes)
end