Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Issue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Issue contains the details of a single issue found by the linter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Issue

Returns a new instance of GoogleCloudApihubV1Issue.



2849
2850
2851
# File 'lib/google/apis/apihub_v1/classes.rb', line 2849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. Rule code unique to each rule defined in linter. Corresponds to the JSON property code

Returns:

  • (String)


2826
2827
2828
# File 'lib/google/apis/apihub_v1/classes.rb', line 2826

def code
  @code
end

#messageString

Required. Human-readable message describing the issue found by the linter. Corresponds to the JSON property message

Returns:

  • (String)


2831
2832
2833
# File 'lib/google/apis/apihub_v1/classes.rb', line 2831

def message
  @message
end

#pathArray<String>

Required. An array of strings indicating the location in the analyzed document where the rule was triggered. Corresponds to the JSON property path

Returns:

  • (Array<String>)


2837
2838
2839
# File 'lib/google/apis/apihub_v1/classes.rb', line 2837

def path
  @path
end

#rangeGoogle::Apis::ApihubV1::GoogleCloudApihubV1Range

Object describing where in the file the issue was found. Corresponds to the JSON property range



2842
2843
2844
# File 'lib/google/apis/apihub_v1/classes.rb', line 2842

def range
  @range
end

#severityString

Required. Severity level of the rule violation. Corresponds to the JSON property severity

Returns:

  • (String)


2847
2848
2849
# File 'lib/google/apis/apihub_v1/classes.rb', line 2847

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2854
2855
2856
2857
2858
2859
2860
# File 'lib/google/apis/apihub_v1/classes.rb', line 2854

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @path = args[:path] if args.key?(:path)
  @range = args[:range] if args.key?(:range)
  @severity = args[:severity] if args.key?(:severity)
end