Class: Google::Apis::ApihubV1::GoogleCloudApihubV1LookupRuntimeProjectAttachmentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The ListRuntimeProjectAttachments method's response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1LookupRuntimeProjectAttachmentResponse

Returns a new instance of GoogleCloudApihubV1LookupRuntimeProjectAttachmentResponse.



3420
3421
3422
# File 'lib/google/apis/apihub_v1/classes.rb', line 3420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#runtime_project_attachmentGoogle::Apis::ApihubV1::GoogleCloudApihubV1RuntimeProjectAttachment

Runtime project attachment represents an attachment from the runtime project to the host project. Api Hub looks for deployments in the attached runtime projects and creates corresponding resources in Api Hub for the discovered deployments. Corresponds to the JSON property runtimeProjectAttachment



3418
3419
3420
# File 'lib/google/apis/apihub_v1/classes.rb', line 3418

def runtime_project_attachment
  @runtime_project_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3425
3426
3427
# File 'lib/google/apis/apihub_v1/classes.rb', line 3425

def update!(**args)
  @runtime_project_attachment = args[:runtime_project_attachment] if args.key?(:runtime_project_attachment)
end