Class: Google::Apis::ApihubV1::GoogleCloudApihubV1McpServerConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

MCP-specific server configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1McpServerConfig

Returns a new instance of GoogleCloudApihubV1McpServerConfig.



3537
3538
3539
# File 'lib/google/apis/apihub_v1/classes.rb', line 3537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apigee_x_target_detailsGoogle::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXTargetDetails

The target configuration for Apigee X. Note: If this API is called while an earlier deployment is still in progress, the earlier deployment will be aborted and a new deployment will be triggered. Corresponds to the JSON property apigeeXTargetDetails



3530
3531
3532
# File 'lib/google/apis/apihub_v1/classes.rb', line 3530

def apigee_x_target_details
  @apigee_x_target_details
end

#toolsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1McpToolConfig>

Required. The tools to expose on the MCP server. Corresponds to the JSON property tools



3535
3536
3537
# File 'lib/google/apis/apihub_v1/classes.rb', line 3535

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3542
3543
3544
3545
# File 'lib/google/apis/apihub_v1/classes.rb', line 3542

def update!(**args)
  @apigee_x_target_details = args[:apigee_x_target_details] if args.key?(:apigee_x_target_details)
  @tools = args[:tools] if args.key?(:tools)
end