Class: Google::Apis::ApihubV1::GoogleCloudApihubV1MetaData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Metadata for the server configuration in Apigee X.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1MetaData

Returns a new instance of GoogleCloudApihubV1MetaData.



3648
3649
3650
# File 'lib/google/apis/apihub_v1/classes.rb', line 3648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description for the server. For apigee target, this will be used as revision description. Corresponds to the JSON property description

Returns:

  • (String)


3640
3641
3642
# File 'lib/google/apis/apihub_v1/classes.rb', line 3640

def description
  @description
end

#display_nameString

Optional. Display name for the server. For apigee target, this will be used as revision display name. Corresponds to the JSON property displayName

Returns:

  • (String)


3646
3647
3648
# File 'lib/google/apis/apihub_v1/classes.rb', line 3646

def display_name
  @display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3653
3654
3655
3656
# File 'lib/google/apis/apihub_v1/classes.rb', line 3653

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
end