Class: Google::Apis::ApihubV1::GoogleCloudApihubV1MultiIntValues

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The config variable value of data type multi int.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1MultiIntValues

Returns a new instance of GoogleCloudApihubV1MultiIntValues.



3477
3478
3479
# File 'lib/google/apis/apihub_v1/classes.rb', line 3477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<Fixnum>

Optional. The config variable value of data type multi int. Corresponds to the JSON property values

Returns:

  • (Array<Fixnum>)


3475
3476
3477
# File 'lib/google/apis/apihub_v1/classes.rb', line 3475

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3482
3483
3484
# File 'lib/google/apis/apihub_v1/classes.rb', line 3482

def update!(**args)
  @values = args[:values] if args.key?(:values)
end