Class: Google::Apis::ApihubV1::GoogleCloudApihubV1MultiSelectValues

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The config variable value of data type multi select.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1MultiSelectValues

Returns a new instance of GoogleCloudApihubV1MultiSelectValues.



3496
3497
3498
# File 'lib/google/apis/apihub_v1/classes.rb', line 3496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigValueOption>

Optional. The config variable value of data type multi select. Corresponds to the JSON property values



3494
3495
3496
# File 'lib/google/apis/apihub_v1/classes.rb', line 3494

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3501
3502
3503
# File 'lib/google/apis/apihub_v1/classes.rb', line 3501

def update!(**args)
  @values = args[:values] if args.key?(:values)
end