Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Oauth2ClientCredentialsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Oauth2ClientCredentialsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Parameters to support Oauth 2.0 client credentials grant authentication. See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Required.
-
#client_secret ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Oauth2ClientCredentialsConfig
constructor
A new instance of GoogleCloudApihubV1Oauth2ClientCredentialsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Oauth2ClientCredentialsConfig
Returns a new instance of GoogleCloudApihubV1Oauth2ClientCredentialsConfig.
3731 3732 3733 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Required. The client identifier.
Corresponds to the JSON property clientId
3724 3725 3726 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3724 def client_id @client_id end |
#client_secret ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property clientSecret
3729 3730 3731 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3729 def client_secret @client_secret end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3736 3737 3738 3739 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3736 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) end |