Class: Google::Apis::ApihubV1::GoogleCloudApihubV1OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1OperationMetadata
constructor
A new instance of GoogleCloudApihubV1OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1OperationMetadata
Returns a new instance of GoogleCloudApihubV1OperationMetadata.
3892 3893 3894 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3856 3857 3858 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3856 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3861 3862 3863 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3861 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3866 3867 3868 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3866 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
3874 3875 3876 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3874 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
3880 3881 3882 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3880 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3885 3886 3887 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3885 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3890 3891 3892 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3890 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3897 3898 3899 3900 3901 3902 3903 3904 3905 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3897 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |