Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Path

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The path details derived from the spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Path

Returns a new instance of GoogleCloudApihubV1Path.



3751
3752
3753
# File 'lib/google/apis/apihub_v1/classes.rb', line 3751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A short description for the path applicable to all operations. Corresponds to the JSON property description

Returns:

  • (String)


3742
3743
3744
# File 'lib/google/apis/apihub_v1/classes.rb', line 3742

def description
  @description
end

#pathString

Optional. Complete path relative to server endpoint. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided. Corresponds to the JSON property path

Returns:

  • (String)


3749
3750
3751
# File 'lib/google/apis/apihub_v1/classes.rb', line 3749

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3756
3757
3758
3759
# File 'lib/google/apis/apihub_v1/classes.rb', line 3756

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @path = args[:path] if args.key?(:path)
end