Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

PluginActionConfig represents the configuration of an action supported by a plugin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1PluginActionConfig

Returns a new instance of GoogleCloudApihubV1PluginActionConfig.



4137
4138
4139
# File 'lib/google/apis/apihub_v1/classes.rb', line 4137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. The description of the operation performed by the action. Corresponds to the JSON property description

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/apihub_v1/classes.rb', line 4120

def description
  @description
end

#display_nameString

Required. The display name of the action. Corresponds to the JSON property displayName

Returns:

  • (String)


4125
4126
4127
# File 'lib/google/apis/apihub_v1/classes.rb', line 4125

def display_name
  @display_name
end

#idString

Required. The id of the action. Corresponds to the JSON property id

Returns:

  • (String)


4130
4131
4132
# File 'lib/google/apis/apihub_v1/classes.rb', line 4130

def id
  @id
end

#trigger_modeString

Required. The trigger mode supported by the action. Corresponds to the JSON property triggerMode

Returns:

  • (String)


4135
4136
4137
# File 'lib/google/apis/apihub_v1/classes.rb', line 4135

def trigger_mode
  @trigger_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4142
4143
4144
4145
4146
4147
# File 'lib/google/apis/apihub_v1/classes.rb', line 4142

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @trigger_mode = args[:trigger_mode] if args.key?(:trigger_mode)
end