Class: Google::Apis::ApihubV1::GoogleCloudApihubV1QueryParam

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An aggregation of HTTP query parameter occurrences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1QueryParam

Returns a new instance of GoogleCloudApihubV1QueryParam.



4410
4411
4412
# File 'lib/google/apis/apihub_v1/classes.rb', line 4410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Optional. The number of occurrences of this query parameter across transactions. Corresponds to the JSON property count

Returns:

  • (Fixnum)


4398
4399
4400
# File 'lib/google/apis/apihub_v1/classes.rb', line 4398

def count
  @count
end

#data_typeString

Optional. Data type of path param Corresponds to the JSON property dataType

Returns:

  • (String)


4403
4404
4405
# File 'lib/google/apis/apihub_v1/classes.rb', line 4403

def data_type
  @data_type
end

#nameString

Required. Name of query param Corresponds to the JSON property name

Returns:

  • (String)


4408
4409
4410
# File 'lib/google/apis/apihub_v1/classes.rb', line 4408

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4415
4416
4417
4418
4419
# File 'lib/google/apis/apihub_v1/classes.rb', line 4415

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @data_type = args[:data_type] if args.key?(:data_type)
  @name = args[:name] if args.key?(:name)
end