Class: Google::Apis::ApihubV1::GoogleCloudApihubV1RuntimeProjectAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Runtime project attachment represents an attachment from the runtime project to the host project. Api Hub looks for deployments in the attached runtime projects and creates corresponding resources in Api Hub for the discovered deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1RuntimeProjectAttachment

Returns a new instance of GoogleCloudApihubV1RuntimeProjectAttachment.



4524
4525
4526
# File 'lib/google/apis/apihub_v1/classes.rb', line 4524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


4508
4509
4510
# File 'lib/google/apis/apihub_v1/classes.rb', line 4508

def create_time
  @create_time
end

#nameString

Identifier. The resource name of a runtime project attachment. Format: " projects/project/locations/location/runtimeProjectAttachments/ runtime_project_attachment". Corresponds to the JSON property name

Returns:

  • (String)


4515
4516
4517
# File 'lib/google/apis/apihub_v1/classes.rb', line 4515

def name
  @name
end

#runtime_projectString

Required. Immutable. Google cloud project name in the format: "projects/abc" or "projects/123". As input, project name with either project id or number are accepted. As output, this field will contain project number. Corresponds to the JSON property runtimeProject

Returns:

  • (String)


4522
4523
4524
# File 'lib/google/apis/apihub_v1/classes.rb', line 4522

def runtime_project
  @runtime_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4529
4530
4531
4532
4533
# File 'lib/google/apis/apihub_v1/classes.rb', line 4529

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @runtime_project = args[:runtime_project] if args.key?(:runtime_project)
end