Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The schema details derived from the spec. Currently, this entity is supported for OpenAPI spec only. For OpenAPI spec, this maps to the schema defined in the definitions section for OpenAPI 2.0 version and in components.schemas section for OpenAPI 3.0 and 3.1 version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Schema

Returns a new instance of GoogleCloudApihubV1Schema.



4556
4557
4558
# File 'lib/google/apis/apihub_v1/classes.rb', line 4556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the schema. This will map to the name of the schema in the spec. Corresponds to the JSON property displayName

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/apihub_v1/classes.rb', line 4547

def display_name
  @display_name
end

#raw_valueString

Output only. The raw value of the schema definition corresponding to the schema name in the spec. Corresponds to the JSON property rawValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4554
4555
4556
# File 'lib/google/apis/apihub_v1/classes.rb', line 4554

def raw_value
  @raw_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4561
4562
4563
4564
# File 'lib/google/apis/apihub_v1/classes.rb', line 4561

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @raw_value = args[:raw_value] if args.key?(:raw_value)
end