Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResult
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents the search results.
Instance Attribute Summary collapse
-
#resource ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApiHubResource
ApiHubResource is one of the resources such as Api, Operation, Deployment, Definition, Spec and Version resources stored in API-Hub.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResult
constructor
A new instance of GoogleCloudApihubV1SearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResult
Returns a new instance of GoogleCloudApihubV1SearchResult.
4444 4445 4446 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApiHubResource
ApiHubResource is one of the resources such as Api, Operation, Deployment,
Definition, Spec and Version resources stored in API-Hub.
Corresponds to the JSON property resource
4442 4443 4444 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4442 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4449 4450 4451 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4449 def update!(**args) @resource = args[:resource] if args.key?(:resource) end |