Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Secret

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Secret provides a reference to entries in Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Secret

Returns a new instance of GoogleCloudApihubV1Secret.



4464
4465
4466
# File 'lib/google/apis/apihub_v1/classes.rb', line 4464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secret_versionString

Required. The resource name of the secret version in the format, format as: projects/*/secrets/*/versions/*. Corresponds to the JSON property secretVersion

Returns:

  • (String)


4462
4463
4464
# File 'lib/google/apis/apihub_v1/classes.rb', line 4462

def secret_version
  @secret_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4469
4470
4471
# File 'lib/google/apis/apihub_v1/classes.rb', line 4469

def update!(**args)
  @secret_version = args[:secret_version] if args.key?(:secret_version)
end