Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Message representing the source environment details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1SourceEnvironment

Returns a new instance of GoogleCloudApihubV1SourceEnvironment.



4719
4720
4721
# File 'lib/google/apis/apihub_v1/classes.rb', line 4719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Optional. The time at which the environment was created at the source. Corresponds to the JSON property createTime

Returns:

  • (String)


4699
4700
4701
# File 'lib/google/apis/apihub_v1/classes.rb', line 4699

def create_time
  @create_time
end

#source_environmentString

Required. The name of the environment at the source. This should map to Deployment. Corresponds to the JSON property sourceEnvironment

Returns:

  • (String)


4705
4706
4707
# File 'lib/google/apis/apihub_v1/classes.rb', line 4705

def source_environment
  @source_environment
end

#source_environment_uriString

The location where additional information about source environments can be found. The location should be relative path of the environment manifest with respect to a plugin instance. Corresponds to the JSON property sourceEnvironmentUri

Returns:

  • (String)


4712
4713
4714
# File 'lib/google/apis/apihub_v1/classes.rb', line 4712

def source_environment_uri
  @source_environment_uri
end

#update_timeString

Optional. The time at which the environment was last updated at the source. Corresponds to the JSON property updateTime

Returns:

  • (String)


4717
4718
4719
# File 'lib/google/apis/apihub_v1/classes.rb', line 4717

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4724
4725
4726
4727
4728
4729
# File 'lib/google/apis/apihub_v1/classes.rb', line 4724

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @source_environment = args[:source_environment] if args.key?(:source_environment)
  @source_environment_uri = args[:source_environment_uri] if args.key?(:source_environment_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end