Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

SpecDetails contains the details parsed from supported spec types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1SpecDetails

Returns a new instance of GoogleCloudApihubV1SpecDetails.



4923
4924
4925
# File 'lib/google/apis/apihub_v1/classes.rb', line 4923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. The description of the spec. Corresponds to the JSON property description

Returns:

  • (String)


4915
4916
4917
# File 'lib/google/apis/apihub_v1/classes.rb', line 4915

def description
  @description
end

#open_api_spec_detailsGoogle::Apis::ApihubV1::GoogleCloudApihubV1OpenApiSpecDetails

OpenApiSpecDetails contains the details parsed from an OpenAPI spec in addition to the fields mentioned in SpecDetails. Corresponds to the JSON property openApiSpecDetails



4921
4922
4923
# File 'lib/google/apis/apihub_v1/classes.rb', line 4921

def open_api_spec_details
  @open_api_spec_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4928
4929
4930
4931
# File 'lib/google/apis/apihub_v1/classes.rb', line 4928

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @open_api_spec_details = args[:open_api_spec_details] if args.key?(:open_api_spec_details)
end