Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SpecMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The metadata associated with a spec of the API version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1SpecMetadata

Returns a new instance of GoogleCloudApihubV1SpecMetadata.



4961
4962
4963
# File 'lib/google/apis/apihub_v1/classes.rb', line 4961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_create_timeString

Optional. Timestamp indicating when the spec was created at the source. Corresponds to the JSON property originalCreateTime

Returns:

  • (String)


4941
4942
4943
# File 'lib/google/apis/apihub_v1/classes.rb', line 4941

def original_create_time
  @original_create_time
end

#original_idString

Optional. The unique identifier of the spec in the system where it was originally created. Corresponds to the JSON property originalId

Returns:

  • (String)


4947
4948
4949
# File 'lib/google/apis/apihub_v1/classes.rb', line 4947

def original_id
  @original_id
end

#original_update_timeString

Required. Timestamp indicating when the spec was last updated at the source. Corresponds to the JSON property originalUpdateTime

Returns:

  • (String)


4952
4953
4954
# File 'lib/google/apis/apihub_v1/classes.rb', line 4952

def original_update_time
  @original_update_time
end

#specGoogle::Apis::ApihubV1::GoogleCloudApihubV1Spec

Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently. Corresponds to the JSON property spec



4959
4960
4961
# File 'lib/google/apis/apihub_v1/classes.rb', line 4959

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4966
4967
4968
4969
4970
4971
# File 'lib/google/apis/apihub_v1/classes.rb', line 4966

def update!(**args)
  @original_create_time = args[:original_create_time] if args.key?(:original_create_time)
  @original_id = args[:original_id] if args.key?(:original_id)
  @original_update_time = args[:original_update_time] if args.key?(:original_update_time)
  @spec = args[:spec] if args.key?(:spec)
end