Class: Google::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The attribute values of data type string or JSON.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1StringAttributeValues

Returns a new instance of GoogleCloudApihubV1StringAttributeValues.



4983
4984
4985
# File 'lib/google/apis/apihub_v1/classes.rb', line 4983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<String>

Required. The attribute values in case attribute data type is string or JSON. Corresponds to the JSON property values

Returns:

  • (Array<String>)


4981
4982
4983
# File 'lib/google/apis/apihub_v1/classes.rb', line 4981

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4988
4989
4990
# File 'lib/google/apis/apihub_v1/classes.rb', line 4988

def update!(**args)
  @values = args[:values] if args.key?(:values)
end