Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ToolAnnotations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Annotations for a Tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ToolAnnotations

Returns a new instance of GoogleCloudApihubV1ToolAnnotations.



5116
5117
5118
# File 'lib/google/apis/apihub_v1/classes.rb', line 5116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_hintsHash<String,String>

Optional. Additional hints which may help tools and not covered in defaults. Corresponds to the JSON property additionalHints

Returns:

  • (Hash<String,String>)


5084
5085
5086
# File 'lib/google/apis/apihub_v1/classes.rb', line 5084

def additional_hints
  @additional_hints
end

#destructive_hintBoolean Also known as: destructive_hint?

Optional. Hint indicating if the tool may have destructive side effects. Corresponds to the JSON property destructiveHint

Returns:

  • (Boolean)


5089
5090
5091
# File 'lib/google/apis/apihub_v1/classes.rb', line 5089

def destructive_hint
  @destructive_hint
end

#idempotent_hintBoolean Also known as: idempotent_hint?

Optional. Hint indicating if the tool is idempotent. Corresponds to the JSON property idempotentHint

Returns:

  • (Boolean)


5095
5096
5097
# File 'lib/google/apis/apihub_v1/classes.rb', line 5095

def idempotent_hint
  @idempotent_hint
end

#open_world_hintBoolean Also known as: open_world_hint?

Optional. Hint indicating if the tool interacts with the open world (e.g., internet). Corresponds to the JSON property openWorldHint

Returns:

  • (Boolean)


5102
5103
5104
# File 'lib/google/apis/apihub_v1/classes.rb', line 5102

def open_world_hint
  @open_world_hint
end

#read_only_hintBoolean Also known as: read_only_hint?

Optional. Hint indicating if the tool is read-only. Corresponds to the JSON property readOnlyHint

Returns:

  • (Boolean)


5108
5109
5110
# File 'lib/google/apis/apihub_v1/classes.rb', line 5108

def read_only_hint
  @read_only_hint
end

#titleString

Optional. A human-readable title for the tool (if different from Tool.title). Corresponds to the JSON property title

Returns:

  • (String)


5114
5115
5116
# File 'lib/google/apis/apihub_v1/classes.rb', line 5114

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5121
5122
5123
5124
5125
5126
5127
5128
# File 'lib/google/apis/apihub_v1/classes.rb', line 5121

def update!(**args)
  @additional_hints = args[:additional_hints] if args.key?(:additional_hints)
  @destructive_hint = args[:destructive_hint] if args.key?(:destructive_hint)
  @idempotent_hint = args[:idempotent_hint] if args.key?(:idempotent_hint)
  @open_world_hint = args[:open_world_hint] if args.key?(:open_world_hint)
  @read_only_hint = args[:read_only_hint] if args.key?(:read_only_hint)
  @title = args[:title] if args.key?(:title)
end