Class: Google::Apis::ApihubV1::GoogleCloudApihubV1UserPasswordConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1UserPasswordConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Parameters to support Username and Password Authentication.
Instance Attribute Summary collapse
-
#password ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1UserPasswordConfig
constructor
A new instance of GoogleCloudApihubV1UserPasswordConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1UserPasswordConfig
Returns a new instance of GoogleCloudApihubV1UserPasswordConfig.
4927 4928 4929 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#password ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property password
4920 4921 4922 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4920 def password @password end |
#username ⇒ String
Required. Username.
Corresponds to the JSON property username
4925 4926 4927 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4925 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4932 4933 4934 4935 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4932 def update!(**args) @password = args[:password] if args.key?(:password) @username = args[:username] if args.key?(:username) end |