Class: Google::Apis::ApihubV1::GoogleCloudApihubV1VersionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1VersionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The metadata associated with a version of the API resource.
Instance Attribute Summary collapse
-
#deployments ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1DeploymentMetadata>
Optional.
-
#original_create_time ⇒ String
Optional.
-
#original_id ⇒ String
Optional.
-
#original_update_time ⇒ String
Required.
-
#specs ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SpecMetadata>
Optional.
-
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1VersionMetadata
constructor
A new instance of GoogleCloudApihubV1VersionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1VersionMetadata
Returns a new instance of GoogleCloudApihubV1VersionMetadata.
5323 5324 5325 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployments ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1DeploymentMetadata>
Optional. The deployments linked to this API version. Note: A particular API
version could be deployed to multiple deployments (for dev deployment, UAT
deployment, etc.)
Corresponds to the JSON property deployments
5293 5294 5295 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5293 def deployments @deployments end |
#original_create_time ⇒ String
Optional. Timestamp indicating when the version was created at the source.
Corresponds to the JSON property originalCreateTime
5298 5299 5300 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5298 def original_create_time @original_create_time end |
#original_id ⇒ String
Optional. The unique identifier of the version in the system where it was
originally created.
Corresponds to the JSON property originalId
5304 5305 5306 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5304 def original_id @original_id end |
#original_update_time ⇒ String
Required. Timestamp indicating when the version was last updated at the source.
Corresponds to the JSON property originalUpdateTime
5309 5310 5311 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5309 def original_update_time @original_update_time end |
#specs ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SpecMetadata>
Optional. The specs associated with this version. Note that an API version can
be associated with multiple specs.
Corresponds to the JSON property specs
5315 5316 5317 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5315 def specs @specs end |
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub. This is also referred to
as the API version.
Corresponds to the JSON property version
5321 5322 5323 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5321 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5328 5329 5330 5331 5332 5333 5334 5335 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5328 def update!(**args) @deployments = args[:deployments] if args.key?(:deployments) @original_create_time = args[:original_create_time] if args.key?(:original_create_time) @original_id = args[:original_id] if args.key?(:original_id) @original_update_time = args[:original_update_time] if args.key?(:original_update_time) @specs = args[:specs] if args.key?(:specs) @version = args[:version] if args.key?(:version) end |