Class: Google::Apis::ApihubV1::GoogleCloudApihubV1AdditionalSpecContent
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1AdditionalSpecContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The additional spec content for the spec. This contains the metadata and the last update time for the additional spec content.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#spec_content_type ⇒ String
Required.
-
#spec_contents ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecContents
The spec contents.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1AdditionalSpecContent
constructor
A new instance of GoogleCloudApihubV1AdditionalSpecContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1AdditionalSpecContent
Returns a new instance of GoogleCloudApihubV1AdditionalSpecContent.
134 135 136 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the spec content was created.
Corresponds to the JSON property createTime
112 113 114 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 112 def create_time @create_time end |
#labels ⇒ Hash<String,String>
Optional. The labels of the spec content e.g. specboost addon version.
Corresponds to the JSON property labels
117 118 119 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 117 def labels @labels end |
#spec_content_type ⇒ String
Required. The type of the spec content.
Corresponds to the JSON property specContentType
122 123 124 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 122 def spec_content_type @spec_content_type end |
#spec_contents ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecContents
The spec contents.
Corresponds to the JSON property specContents
127 128 129 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 127 def spec_contents @spec_contents end |
#update_time ⇒ String
Output only. The time at which the spec content was last updated.
Corresponds to the JSON property updateTime
132 133 134 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 132 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
139 140 141 142 143 144 145 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 139 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @labels = args[:labels] if args.key?(:labels) @spec_content_type = args[:spec_content_type] if args.key?(:spec_content_type) @spec_contents = args[:spec_contents] if args.key?(:spec_contents) @update_time = args[:update_time] if args.key?(:update_time) end |