Class: Google::Apis::ApihubV1::GoogleCloudApihubV1AddonConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1AddonConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Configuration for the addon.
Instance Attribute Summary collapse
-
#all_data_addon_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AllDataAddonConfig
Configuration for addons which act on all data in the API hub.
-
#gateway_plugin_addon_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginAddonConfig
Configuration for gateway plugin addons.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1AddonConfig
constructor
A new instance of GoogleCloudApihubV1AddonConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1AddonConfig
Returns a new instance of GoogleCloudApihubV1AddonConfig.
227 228 229 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_data_addon_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AllDataAddonConfig
Configuration for addons which act on all data in the API hub. This is used to
specify if the addon is enabled for all data in the API hub.
Corresponds to the JSON property allDataAddonConfig
219 220 221 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 219 def all_data_addon_config @all_data_addon_config end |
#gateway_plugin_addon_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginAddonConfig
Configuration for gateway plugin addons. This is used to specify the list of
gateway plugin configs for which the addon is enabled.
Corresponds to the JSON property gatewayPluginAddonConfig
225 226 227 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 225 def gateway_plugin_addon_config @gateway_plugin_addon_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
232 233 234 235 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 232 def update!(**args) @all_data_addon_config = args[:all_data_addon_config] if args.key?(:all_data_addon_config) @gateway_plugin_addon_config = args[:gateway_plugin_addon_config] if args.key?(:gateway_plugin_addon_config) end |