Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeEdgeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeEdgeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Configuration for Apigee Edge gateways. Applicability of a filter is determined by the filter being provided. If none of the filters are provided the addon will be enabled for all data brought in by the gateway plugin instance.
Instance Attribute Summary collapse
-
#environment_filter ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1EnvironmentFilter
Filter for environments.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ApigeeEdgeConfig
constructor
A new instance of GoogleCloudApihubV1ApigeeEdgeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ApigeeEdgeConfig
Returns a new instance of GoogleCloudApihubV1ApigeeEdgeConfig.
783 784 785 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#environment_filter ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1EnvironmentFilter
Filter for environments.
Corresponds to the JSON property environmentFilter
781 782 783 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 781 def environment_filter @environment_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
788 789 790 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 788 def update!(**args) @environment_filter = args[:environment_filter] if args.key?(:environment_filter) end |