Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXTargetDetails
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXTargetDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The target configuration for Apigee X. Note: If this API is called while an earlier deployment is still in progress, the earlier deployment will be aborted and a new deployment will be triggered.
Instance Attribute Summary collapse
-
#deployed_revision ⇒ String
Output only.
-
#environment ⇒ String
Required.
-
#metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MetaData
Metadata for the server configuration in Apigee X.
-
#proxy ⇒ String
Required.
-
#target_project ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ApigeeXTargetDetails
constructor
A new instance of GoogleCloudApihubV1ApigeeXTargetDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ApigeeXTargetDetails
Returns a new instance of GoogleCloudApihubV1ApigeeXTargetDetails.
870 871 872 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_revision ⇒ String
Output only. The revision number of the Apigee proxy that was deployed.
Corresponds to the JSON property deployedRevision
846 847 848 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 846 def deployed_revision @deployed_revision end |
#environment ⇒ String
Required. The specific Apigee environment where the server will be deployed.
Corresponds to the JSON property environment
851 852 853 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 851 def environment @environment end |
#metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MetaData
Metadata for the server configuration in Apigee X.
Corresponds to the JSON property metadata
856 857 858 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 856 def @metadata end |
#proxy ⇒ String
Required. This name identifies the proxy resource in Apigee. It typically
follows a standard alphanumeric format (e.g., "mcp-discovery-server").
Corresponds to the JSON property proxy
862 863 864 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 862 def proxy @proxy end |
#target_project ⇒ String
Required. The runtime project that hosts the Apigee X organization. This must
be one of the runtime projects attached to the API Hub host project.
Corresponds to the JSON property targetProject
868 869 870 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 868 def target_project @target_project end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
875 876 877 878 879 880 881 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 875 def update!(**args) @deployed_revision = args[:deployed_revision] if args.key?(:deployed_revision) @environment = args[:environment] if args.key?(:environment) @metadata = args[:metadata] if args.key?(:metadata) @proxy = args[:proxy] if args.key?(:proxy) @target_project = args[:target_project] if args.key?(:target_project) end |