Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
ConfigVariable represents a additional configuration variable present in a PluginInstance Config or AuthConfig, based on a ConfigVariableTemplate.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Optional.
-
#enum_value ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigValueOption
ConfigValueOption represents an option for a config variable of type enum or multi select.
-
#int_value ⇒ Fixnum
Optional.
-
#key ⇒ String
Output only.
-
#multi_int_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiIntValues
The config variable value of data type multi int.
-
#multi_select_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiSelectValues
The config variable value of data type multi select.
-
#multi_string_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiStringValues
The config variable value of data type multi string.
-
#secret_value ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
-
#string_value ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ConfigVariable
constructor
A new instance of GoogleCloudApihubV1ConfigVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ConfigVariable
Returns a new instance of GoogleCloudApihubV1ConfigVariable.
1273 1274 1275 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Optional. The config variable value in case of config variable of type boolean.
Corresponds to the JSON property boolValue
1229 1230 1231 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1229 def bool_value @bool_value end |
#enum_value ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigValueOption
ConfigValueOption represents an option for a config variable of type enum or
multi select.
Corresponds to the JSON property enumValue
1236 1237 1238 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1236 def enum_value @enum_value end |
#int_value ⇒ Fixnum
Optional. The config variable value in case of config variable of type integer.
Corresponds to the JSON property intValue
1241 1242 1243 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1241 def int_value @int_value end |
#key ⇒ String
Output only. Key will be the id to uniquely identify the config variable.
Corresponds to the JSON property key
1246 1247 1248 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1246 def key @key end |
#multi_int_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiIntValues
The config variable value of data type multi int.
Corresponds to the JSON property multiIntValues
1251 1252 1253 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1251 def multi_int_values @multi_int_values end |
#multi_select_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiSelectValues
The config variable value of data type multi select.
Corresponds to the JSON property multiSelectValues
1256 1257 1258 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1256 def multi_select_values @multi_select_values end |
#multi_string_values ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1MultiStringValues
The config variable value of data type multi string.
Corresponds to the JSON property multiStringValues
1261 1262 1263 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1261 def multi_string_values @multi_string_values end |
#secret_value ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Secret
Secret provides a reference to entries in Secret Manager.
Corresponds to the JSON property secretValue
1266 1267 1268 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1266 def secret_value @secret_value end |
#string_value ⇒ String
Optional. The config variable value in case of config variable of type string.
Corresponds to the JSON property stringValue
1271 1272 1273 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1271 def string_value @string_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1278 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @enum_value = args[:enum_value] if args.key?(:enum_value) @int_value = args[:int_value] if args.key?(:int_value) @key = args[:key] if args.key?(:key) @multi_int_values = args[:multi_int_values] if args.key?(:multi_int_values) @multi_select_values = args[:multi_select_values] if args.key?(:multi_select_values) @multi_string_values = args[:multi_string_values] if args.key?(:multi_string_values) @secret_value = args[:secret_value] if args.key?(:secret_value) @string_value = args[:string_value] if args.key?(:string_value) end |