Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Curation
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Curation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A curation resource in the API Hub.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#endpoint ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
The endpoint to be triggered for curation.
-
#last_execution_error_code ⇒ String
Output only.
-
#last_execution_error_message ⇒ String
Output only.
-
#last_execution_state ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#plugin_instance_actions ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceActionId>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Curation
constructor
A new instance of GoogleCloudApihubV1Curation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Curation
Returns a new instance of GoogleCloudApihubV1Curation.
1412 1413 1414 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the curation was created.
Corresponds to the JSON property createTime
1358 1359 1360 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1358 def create_time @create_time end |
#description ⇒ String
Optional. The description of the curation.
Corresponds to the JSON property description
1363 1364 1365 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1363 def description @description end |
#display_name ⇒ String
Required. The display name of the curation.
Corresponds to the JSON property displayName
1368 1369 1370 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1368 def display_name @display_name end |
#endpoint ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
The endpoint to be triggered for curation. The endpoint will be invoked with a
request payload containing ApiMetadata. Response should contain curated data
in the form of ApiMetadata.
Corresponds to the JSON property endpoint
1375 1376 1377 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1375 def endpoint @endpoint end |
#last_execution_error_code ⇒ String
Output only. The error code of the last execution of the curation. The error
code is populated only when the last execution state is failed.
Corresponds to the JSON property lastExecutionErrorCode
1381 1382 1383 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1381 def last_execution_error_code @last_execution_error_code end |
#last_execution_error_message ⇒ String
Output only. Error message describing the failure, if any, during the last
execution of the curation.
Corresponds to the JSON property lastExecutionErrorMessage
1387 1388 1389 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1387 def @last_execution_error_message end |
#last_execution_state ⇒ String
Output only. The last execution state of the curation.
Corresponds to the JSON property lastExecutionState
1392 1393 1394 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1392 def last_execution_state @last_execution_state end |
#name ⇒ String
Identifier. The name of the curation. Format: projects/project/locations/
location/curations/curation`
Corresponds to the JSON propertyname`
1398 1399 1400 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1398 def name @name end |
#plugin_instance_actions ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceActionId>
Output only. The plugin instances and associated actions that are using the
curation. Note: A particular curation could be used by multiple plugin
instances or multiple actions in a plugin instance.
Corresponds to the JSON property pluginInstanceActions
1405 1406 1407 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1405 def plugin_instance_actions @plugin_instance_actions end |
#update_time ⇒ String
Output only. The time at which the curation was last updated.
Corresponds to the JSON property updateTime
1410 1411 1412 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1410 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1417 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @endpoint = args[:endpoint] if args.key?(:endpoint) @last_execution_error_code = args[:last_execution_error_code] if args.key?(:last_execution_error_code) @last_execution_error_message = args[:last_execution_error_message] if args.key?(:last_execution_error_message) @last_execution_state = args[:last_execution_state] if args.key?(:last_execution_state) @name = args[:name] if args.key?(:name) @plugin_instance_actions = args[:plugin_instance_actions] if args.key?(:plugin_instance_actions) @update_time = args[:update_time] if args.key?(:update_time) end |