Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Dependency
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Dependency
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A dependency resource defined in the API hub describes a dependency directed from a consumer to a supplier entity. A dependency can be defined between two Operations or between an Operation and External API.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional.
-
#consumer ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
Reference to an entity participating in a dependency.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovery_mode ⇒ String
Output only.
-
#error_detail ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyErrorDetail
Details describing error condition of a dependency.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#supplier ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
Reference to an entity participating in a dependency.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Dependency
constructor
A new instance of GoogleCloudApihubV1Dependency.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Dependency
Returns a new instance of GoogleCloudApihubV1Dependency.
1606 1607 1608 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional. The list of user defined attributes associated with the dependency
resource. The key is the attribute name. It will be of the format: projects/
project/locations/location/attributes/attribute`. The value is the
attribute values associated with the resource.
Corresponds to the JSON propertyattributes`
1558 1559 1560 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1558 def attributes @attributes end |
#consumer ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
Reference to an entity participating in a dependency.
Corresponds to the JSON property consumer
1563 1564 1565 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1563 def consumer @consumer end |
#create_time ⇒ String
Output only. The time at which the dependency was created.
Corresponds to the JSON property createTime
1568 1569 1570 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1568 def create_time @create_time end |
#description ⇒ String
Optional. Human readable description corresponding of the dependency.
Corresponds to the JSON property description
1573 1574 1575 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1573 def description @description end |
#discovery_mode ⇒ String
Output only. Discovery mode of the dependency.
Corresponds to the JSON property discoveryMode
1578 1579 1580 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1578 def discovery_mode @discovery_mode end |
#error_detail ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyErrorDetail
Details describing error condition of a dependency.
Corresponds to the JSON property errorDetail
1583 1584 1585 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1583 def error_detail @error_detail end |
#name ⇒ String
Identifier. The name of the dependency in the API Hub. Format: projects/
project/locations/location/dependencies/dependency`
Corresponds to the JSON propertyname`
1589 1590 1591 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1589 def name @name end |
#state ⇒ String
Output only. State of the dependency.
Corresponds to the JSON property state
1594 1595 1596 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1594 def state @state end |
#supplier ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1DependencyEntityReference
Reference to an entity participating in a dependency.
Corresponds to the JSON property supplier
1599 1600 1601 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1599 def supplier @supplier end |
#update_time ⇒ String
Output only. The time at which the dependency was last updated.
Corresponds to the JSON property updateTime
1604 1605 1606 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1604 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1611 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @consumer = args[:consumer] if args.key?(:consumer) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovery_mode = args[:discovery_mode] if args.key?(:discovery_mode) @error_detail = args[:error_detail] if args.key?(:error_detail) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @supplier = args[:supplier] if args.key?(:supplier) @update_time = args[:update_time] if args.key?(:update_time) end |