Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API.
Instance Attribute Summary collapse
-
#api_versions ⇒ Array<String>
Output only.
-
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional.
-
#create_time ⇒ String
Output only.
-
#deployment_type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#endpoints ⇒ Array<String>
Required.
-
#environment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#management_url ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#name ⇒ String
Identifier.
-
#resource_uri ⇒ String
Required.
-
#slo ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#source_environment ⇒ String
Optional.
-
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only.
-
#source_project ⇒ String
Optional.
-
#source_uri ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Deployment
constructor
A new instance of GoogleCloudApihubV1Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Deployment
Returns a new instance of GoogleCloudApihubV1Deployment.
1861 1862 1863 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_versions ⇒ Array<String>
Output only. The API versions linked to this deployment. Note: A particular
deployment could be linked to multiple different API versions (of same or
different APIs).
Corresponds to the JSON property apiVersions
1761 1762 1763 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1761 def api_versions @api_versions end |
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional. The list of user defined attributes associated with the deployment
resource. The key is the attribute name. It will be of the format: projects/
project/locations/location/attributes/attribute`. The value is the
attribute values associated with the resource.
Corresponds to the JSON propertyattributes`
1769 1770 1771 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1769 def attributes @attributes end |
#create_time ⇒ String
Output only. The time at which the deployment was created.
Corresponds to the JSON property createTime
1774 1775 1776 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1774 def create_time @create_time end |
#deployment_type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property deploymentType
1779 1780 1781 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1779 def deployment_type @deployment_type end |
#description ⇒ String
Optional. The description of the deployment.
Corresponds to the JSON property description
1784 1785 1786 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1784 def description @description end |
#display_name ⇒ String
Required. The display name of the deployment.
Corresponds to the JSON property displayName
1789 1790 1791 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1789 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
1794 1795 1796 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1794 def documentation @documentation end |
#endpoints ⇒ Array<String>
Required. The endpoints at which this deployment resource is listening for API
requests. This could be a list of complete URIs, hostnames or an IP addresses.
Corresponds to the JSON property endpoints
1800 1801 1802 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1800 def endpoints @endpoints end |
#environment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property environment
1805 1806 1807 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1805 def environment @environment end |
#management_url ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property managementUrl
1810 1811 1812 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1810 def management_url @management_url end |
#name ⇒ String
Identifier. The name of the deployment. Format: projects/project/locations/
location/deployments/deployment`
Corresponds to the JSON propertyname`
1816 1817 1818 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1816 def name @name end |
#resource_uri ⇒ String
Required. The resource URI identifies the deployment within its gateway. For
Apigee gateways, its recommended to use the format: organizations/org/
environments/env/apis/api. For ex: if a proxy with name orders is
deployed in staging environment of cymbal organization, the resource URI
would be: organizations/cymbal/environments/staging/apis/orders.
Corresponds to the JSON property resourceUri
1825 1826 1827 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1825 def resource_uri @resource_uri end |
#slo ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property slo
1830 1831 1832 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1830 def slo @slo end |
#source_environment ⇒ String
Optional. The environment at source for the deployment. For example: prod, dev,
staging, etc.
Corresponds to the JSON property sourceEnvironment
1836 1837 1838 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1836 def source_environment @source_environment end |
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only. The list of sources and metadata from the sources of the
deployment.
Corresponds to the JSON property sourceMetadata
1842 1843 1844 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1842 def @source_metadata end |
#source_project ⇒ String
Optional. The project to which the deployment belongs. For Google Cloud
gateways, this will refer to the project identifier. For others like Edge/OPDK,
this will refer to the org identifier.
Corresponds to the JSON property sourceProject
1849 1850 1851 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1849 def source_project @source_project end |
#source_uri ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property sourceUri
1854 1855 1856 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1854 def source_uri @source_uri end |
#update_time ⇒ String
Output only. The time at which the deployment was last updated.
Corresponds to the JSON property updateTime
1859 1860 1861 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1859 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1866 def update!(**args) @api_versions = args[:api_versions] if args.key?(:api_versions) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @endpoints = args[:endpoints] if args.key?(:endpoints) @environment = args[:environment] if args.key?(:environment) @management_url = args[:management_url] if args.key?(:management_url) @name = args[:name] if args.key?(:name) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @slo = args[:slo] if args.key?(:slo) @source_environment = args[:source_environment] if args.key?(:source_environment) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @source_project = args[:source_project] if args.key?(:source_project) @source_uri = args[:source_uri] if args.key?(:source_uri) @update_time = args[:update_time] if args.key?(:update_time) end |