Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Deployment

Returns a new instance of GoogleCloudApihubV1Deployment.



1795
1796
1797
# File 'lib/google/apis/apihub_v1/classes.rb', line 1795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionsArray<String>

Output only. The API versions linked to this deployment. Note: A particular deployment could be linked to multiple different API versions (of same or different APIs). Corresponds to the JSON property apiVersions

Returns:

  • (Array<String>)


1695
1696
1697
# File 'lib/google/apis/apihub_v1/classes.rb', line 1695

def api_versions
  @api_versions
end

#attributesHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>

Optional. The list of user defined attributes associated with the deployment resource. The key is the attribute name. It will be of the format: projects/ project/locations/location/attributes/attribute`. The value is the attribute values associated with the resource. Corresponds to the JSON propertyattributes`



1703
1704
1705
# File 'lib/google/apis/apihub_v1/classes.rb', line 1703

def attributes
  @attributes
end

#create_timeString

Output only. The time at which the deployment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1708
1709
1710
# File 'lib/google/apis/apihub_v1/classes.rb', line 1708

def create_time
  @create_time
end

#deployment_typeGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property deploymentType



1713
1714
1715
# File 'lib/google/apis/apihub_v1/classes.rb', line 1713

def deployment_type
  @deployment_type
end

#descriptionString

Optional. The description of the deployment. Corresponds to the JSON property description

Returns:

  • (String)


1718
1719
1720
# File 'lib/google/apis/apihub_v1/classes.rb', line 1718

def description
  @description
end

#display_nameString

Required. The display name of the deployment. Corresponds to the JSON property displayName

Returns:

  • (String)


1723
1724
1725
# File 'lib/google/apis/apihub_v1/classes.rb', line 1723

def display_name
  @display_name
end

#documentationGoogle::Apis::ApihubV1::GoogleCloudApihubV1Documentation

Documentation details. Corresponds to the JSON property documentation



1728
1729
1730
# File 'lib/google/apis/apihub_v1/classes.rb', line 1728

def documentation
  @documentation
end

#endpointsArray<String>

Required. The endpoints at which this deployment resource is listening for API requests. This could be a list of complete URIs, hostnames or an IP addresses. Corresponds to the JSON property endpoints

Returns:

  • (Array<String>)


1734
1735
1736
# File 'lib/google/apis/apihub_v1/classes.rb', line 1734

def endpoints
  @endpoints
end

#environmentGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property environment



1739
1740
1741
# File 'lib/google/apis/apihub_v1/classes.rb', line 1739

def environment
  @environment
end

#management_urlGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property managementUrl



1744
1745
1746
# File 'lib/google/apis/apihub_v1/classes.rb', line 1744

def management_url
  @management_url
end

#nameString

Identifier. The name of the deployment. Format: projects/project/locations/ location/deployments/deployment` Corresponds to the JSON propertyname`

Returns:

  • (String)


1750
1751
1752
# File 'lib/google/apis/apihub_v1/classes.rb', line 1750

def name
  @name
end

#resource_uriString

Required. The resource URI identifies the deployment within its gateway. For Apigee gateways, its recommended to use the format: organizations/org/ environments/env/apis/api. For ex: if a proxy with name orders is deployed in staging environment of cymbal organization, the resource URI would be: organizations/cymbal/environments/staging/apis/orders. Corresponds to the JSON property resourceUri

Returns:

  • (String)


1759
1760
1761
# File 'lib/google/apis/apihub_v1/classes.rb', line 1759

def resource_uri
  @resource_uri
end

#sloGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property slo



1764
1765
1766
# File 'lib/google/apis/apihub_v1/classes.rb', line 1764

def slo
  @slo
end

#source_environmentString

Optional. The environment at source for the deployment. For example: prod, dev, staging, etc. Corresponds to the JSON property sourceEnvironment

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/apihub_v1/classes.rb', line 1770

def source_environment
  @source_environment
end

#source_metadataArray<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>

Output only. The list of sources and metadata from the sources of the deployment. Corresponds to the JSON property sourceMetadata



1776
1777
1778
# File 'lib/google/apis/apihub_v1/classes.rb', line 1776

def 
  @source_metadata
end

#source_projectString

Optional. The project to which the deployment belongs. For Google Cloud gateways, this will refer to the project identifier. For others like Edge/OPDK, this will refer to the org identifier. Corresponds to the JSON property sourceProject

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/apihub_v1/classes.rb', line 1783

def source_project
  @source_project
end

#source_uriGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property sourceUri



1788
1789
1790
# File 'lib/google/apis/apihub_v1/classes.rb', line 1788

def source_uri
  @source_uri
end

#update_timeString

Output only. The time at which the deployment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1793
1794
1795
# File 'lib/google/apis/apihub_v1/classes.rb', line 1793

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
# File 'lib/google/apis/apihub_v1/classes.rb', line 1800

def update!(**args)
  @api_versions = args[:api_versions] if args.key?(:api_versions)
  @attributes = args[:attributes] if args.key?(:attributes)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @environment = args[:environment] if args.key?(:environment)
  @management_url = args[:management_url] if args.key?(:management_url)
  @name = args[:name] if args.key?(:name)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @slo = args[:slo] if args.key?(:slo)
  @source_environment = args[:source_environment] if args.key?(:source_environment)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @source_project = args[:source_project] if args.key?(:source_project)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end