Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DeploymentMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1DeploymentMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The metadata associated with a deployment.
Instance Attribute Summary collapse
-
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted.
-
#original_create_time ⇒ String
Optional.
-
#original_id ⇒ String
Optional.
-
#original_update_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1DeploymentMetadata
constructor
A new instance of GoogleCloudApihubV1DeploymentMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1DeploymentMetadata
Returns a new instance of GoogleCloudApihubV1DeploymentMetadata.
1851 1852 1853 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted. A deployment could represent
an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud
services as well. A deployment entity is a root level entity in the API hub
and exists independent of any API.
Corresponds to the JSON property deployment
1832 1833 1834 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1832 def deployment @deployment end |
#original_create_time ⇒ String
Optional. Timestamp indicating when the deployment was created at the source.
Corresponds to the JSON property originalCreateTime
1837 1838 1839 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1837 def original_create_time @original_create_time end |
#original_id ⇒ String
Optional. The unique identifier of the deployment in the system where it was
originally created.
Corresponds to the JSON property originalId
1843 1844 1845 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1843 def original_id @original_id end |
#original_update_time ⇒ String
Required. Timestamp indicating when the deployment was last updated at the
source.
Corresponds to the JSON property originalUpdateTime
1849 1850 1851 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1849 def original_update_time @original_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1856 1857 1858 1859 1860 1861 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1856 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @original_create_time = args[:original_create_time] if args.key?(:original_create_time) @original_id = args[:original_id] if args.key?(:original_id) @original_update_time = args[:original_update_time] if args.key?(:original_update_time) end |