Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiObservation
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiObservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Respresents an API Observation observed in one of the sources.
Instance Attribute Summary collapse
-
#api_operation_count ⇒ Fixnum
Optional.
-
#create_time ⇒ String
Output only.
-
#hostname ⇒ String
Optional.
-
#known_operations_count ⇒ Fixnum
Output only.
-
#last_event_detected_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#origin ⇒ String
Optional.
-
#server_ips ⇒ Array<String>
Optional.
-
#source_locations ⇒ Array<String>
Optional.
-
#source_metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata
SourceMetadata represents the metadata for a resource at the source.
-
#source_types ⇒ Array<String>
Optional.
-
#style ⇒ String
Optional.
-
#unknown_operations_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiObservation
constructor
A new instance of GoogleCloudApihubV1DiscoveredApiObservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiObservation
Returns a new instance of GoogleCloudApihubV1DiscoveredApiObservation.
2041 2042 2043 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_operation_count ⇒ Fixnum
Optional. The number of observed API Operations.
Corresponds to the JSON property apiOperationCount
1969 1970 1971 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1969 def api_operation_count @api_operation_count end |
#create_time ⇒ String
Output only. Create time stamp of the observation in API Hub.
Corresponds to the JSON property createTime
1974 1975 1976 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1974 def create_time @create_time end |
#hostname ⇒ String
Optional. The hostname of requests processed for this Observation.
Corresponds to the JSON property hostname
1979 1980 1981 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1979 def hostname @hostname end |
#known_operations_count ⇒ Fixnum
Output only. The number of known API Operations.
Corresponds to the JSON property knownOperationsCount
1984 1985 1986 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1984 def known_operations_count @known_operations_count end |
#last_event_detected_time ⇒ String
Optional. Last event detected time stamp
Corresponds to the JSON property lastEventDetectedTime
1989 1990 1991 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1989 def last_event_detected_time @last_event_detected_time end |
#name ⇒ String
Identifier. The name of the discovered API Observation. Format: projects/
project/locations/location/discoveredApiObservations/
discovered_api_observation`
Corresponds to the JSON propertyname`
1996 1997 1998 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1996 def name @name end |
#origin ⇒ String
Optional. For an observation pushed from a Google Cloud resource, this would
be the Google Cloud project id.
Corresponds to the JSON property origin
2002 2003 2004 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2002 def origin @origin end |
#server_ips ⇒ Array<String>
Optional. The IP address (IPv4 or IPv6) of the origin server that the request
was sent to. This field can include port information. Examples: "192.168.1.1"
, "10.0.0.1:80", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property serverIps
2009 2010 2011 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2009 def server_ips @server_ips end |
#source_locations ⇒ Array<String>
Optional. The location of the observation source.
Corresponds to the JSON property sourceLocations
2014 2015 2016 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2014 def source_locations @source_locations end |
#source_metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata
SourceMetadata represents the metadata for a resource at the source.
Corresponds to the JSON property sourceMetadata
2019 2020 2021 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2019 def @source_metadata end |
#source_types ⇒ Array<String>
Optional. The type of the source from which the observation was collected.
Corresponds to the JSON property sourceTypes
2024 2025 2026 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2024 def source_types @source_types end |
#style ⇒ String
Optional. Style of ApiObservation
Corresponds to the JSON property style
2029 2030 2031 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2029 def style @style end |
#unknown_operations_count ⇒ Fixnum
Output only. The number of unknown API Operations.
Corresponds to the JSON property unknownOperationsCount
2034 2035 2036 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2034 def unknown_operations_count @unknown_operations_count end |
#update_time ⇒ String
Output only. Update time stamp of the observation in API Hub.
Corresponds to the JSON property updateTime
2039 2040 2041 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2039 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2046 def update!(**args) @api_operation_count = args[:api_operation_count] if args.key?(:api_operation_count) @create_time = args[:create_time] if args.key?(:create_time) @hostname = args[:hostname] if args.key?(:hostname) @known_operations_count = args[:known_operations_count] if args.key?(:known_operations_count) @last_event_detected_time = args[:last_event_detected_time] if args.key?(:last_event_detected_time) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) @server_ips = args[:server_ips] if args.key?(:server_ips) @source_locations = args[:source_locations] if args.key?(:source_locations) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @source_types = args[:source_types] if args.key?(:source_types) @style = args[:style] if args.key?(:style) @unknown_operations_count = args[:unknown_operations_count] if args.key?(:unknown_operations_count) @update_time = args[:update_time] if args.key?(:update_time) end |