Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiObservation
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiObservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Respresents an API Observation observed in one of the sources.
Instance Attribute Summary collapse
-
#api_operation_count ⇒ Fixnum
Optional.
-
#create_time ⇒ String
Output only.
-
#hostname ⇒ String
Optional.
-
#known_operations_count ⇒ Fixnum
Output only.
-
#last_event_detected_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#origin ⇒ String
Optional.
-
#server_ips ⇒ Array<String>
Optional.
-
#source_locations ⇒ Array<String>
Optional.
-
#source_metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata
SourceMetadata represents the metadata for a resource at the source.
-
#source_types ⇒ Array<String>
Optional.
-
#style ⇒ String
Optional.
-
#unknown_operations_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiObservation
constructor
A new instance of GoogleCloudApihubV1DiscoveredApiObservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiObservation
Returns a new instance of GoogleCloudApihubV1DiscoveredApiObservation.
1975 1976 1977 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_operation_count ⇒ Fixnum
Optional. The number of observed API Operations.
Corresponds to the JSON property apiOperationCount
1903 1904 1905 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1903 def api_operation_count @api_operation_count end |
#create_time ⇒ String
Output only. Create time stamp of the observation in API Hub.
Corresponds to the JSON property createTime
1908 1909 1910 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1908 def create_time @create_time end |
#hostname ⇒ String
Optional. The hostname of requests processed for this Observation.
Corresponds to the JSON property hostname
1913 1914 1915 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1913 def hostname @hostname end |
#known_operations_count ⇒ Fixnum
Output only. The number of known API Operations.
Corresponds to the JSON property knownOperationsCount
1918 1919 1920 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1918 def known_operations_count @known_operations_count end |
#last_event_detected_time ⇒ String
Optional. Last event detected time stamp
Corresponds to the JSON property lastEventDetectedTime
1923 1924 1925 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1923 def last_event_detected_time @last_event_detected_time end |
#name ⇒ String
Identifier. The name of the discovered API Observation. Format: projects/
project/locations/location/discoveredApiObservations/
discovered_api_observation`
Corresponds to the JSON propertyname`
1930 1931 1932 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1930 def name @name end |
#origin ⇒ String
Optional. For an observation pushed from a Google Cloud resource, this would
be the Google Cloud project id.
Corresponds to the JSON property origin
1936 1937 1938 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1936 def origin @origin end |
#server_ips ⇒ Array<String>
Optional. The IP address (IPv4 or IPv6) of the origin server that the request
was sent to. This field can include port information. Examples: "192.168.1.1"
, "10.0.0.1:80", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property serverIps
1943 1944 1945 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1943 def server_ips @server_ips end |
#source_locations ⇒ Array<String>
Optional. The location of the observation source.
Corresponds to the JSON property sourceLocations
1948 1949 1950 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1948 def source_locations @source_locations end |
#source_metadata ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata
SourceMetadata represents the metadata for a resource at the source.
Corresponds to the JSON property sourceMetadata
1953 1954 1955 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1953 def @source_metadata end |
#source_types ⇒ Array<String>
Optional. The type of the source from which the observation was collected.
Corresponds to the JSON property sourceTypes
1958 1959 1960 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1958 def source_types @source_types end |
#style ⇒ String
Optional. Style of ApiObservation
Corresponds to the JSON property style
1963 1964 1965 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1963 def style @style end |
#unknown_operations_count ⇒ Fixnum
Output only. The number of unknown API Operations.
Corresponds to the JSON property unknownOperationsCount
1968 1969 1970 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1968 def unknown_operations_count @unknown_operations_count end |
#update_time ⇒ String
Output only. Update time stamp of the observation in API Hub.
Corresponds to the JSON property updateTime
1973 1974 1975 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1973 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 1980 def update!(**args) @api_operation_count = args[:api_operation_count] if args.key?(:api_operation_count) @create_time = args[:create_time] if args.key?(:create_time) @hostname = args[:hostname] if args.key?(:hostname) @known_operations_count = args[:known_operations_count] if args.key?(:known_operations_count) @last_event_detected_time = args[:last_event_detected_time] if args.key?(:last_event_detected_time) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) @server_ips = args[:server_ips] if args.key?(:server_ips) @source_locations = args[:source_locations] if args.key?(:source_locations) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @source_types = args[:source_types] if args.key?(:source_types) @style = args[:style] if args.key?(:style) @unknown_operations_count = args[:unknown_operations_count] if args.key?(:unknown_operations_count) @update_time = args[:update_time] if args.key?(:update_time) end |