Class: Google::Apis::ApihubV1::GoogleCloudApihubV1DiscoveredApiOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

DiscoveredApiOperation represents an API Operation observed in one of the sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1DiscoveredApiOperation

Returns a new instance of GoogleCloudApihubV1DiscoveredApiOperation.



2058
2059
2060
# File 'lib/google/apis/apihub_v1/classes.rb', line 2058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationString

Output only. The classification of the discovered API operation. Corresponds to the JSON property classification

Returns:

  • (String)


2006
2007
2008
# File 'lib/google/apis/apihub_v1/classes.rb', line 2006

def classification
  @classification
end

#countFixnum

Optional. The number of occurrences of this API Operation. Corresponds to the JSON property count

Returns:

  • (Fixnum)


2011
2012
2013
# File 'lib/google/apis/apihub_v1/classes.rb', line 2011

def count
  @count
end

#create_timeString

Output only. Create time stamp of the discovered API operation in API Hub. Corresponds to the JSON property createTime

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/apihub_v1/classes.rb', line 2016

def create_time
  @create_time
end

#first_seen_timeString

Optional. First seen time stamp Corresponds to the JSON property firstSeenTime

Returns:

  • (String)


2021
2022
2023
# File 'lib/google/apis/apihub_v1/classes.rb', line 2021

def first_seen_time
  @first_seen_time
end

#http_operationGoogle::Apis::ApihubV1::GoogleCloudApihubV1HttpOperationDetails

An HTTP-based API Operation, sometimes called a "REST" Operation. Corresponds to the JSON property httpOperation



2026
2027
2028
# File 'lib/google/apis/apihub_v1/classes.rb', line 2026

def http_operation
  @http_operation
end

#last_seen_timeString

Optional. Last seen time stamp Corresponds to the JSON property lastSeenTime

Returns:

  • (String)


2031
2032
2033
# File 'lib/google/apis/apihub_v1/classes.rb', line 2031

def last_seen_time
  @last_seen_time
end

#match_resultsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1MatchResult>

Output only. The list of matched results for the discovered API operation. This will be populated only if the classification is known. The current usecase is for a single match. Keeping it repeated to support multiple matches in future. Corresponds to the JSON property matchResults



2039
2040
2041
# File 'lib/google/apis/apihub_v1/classes.rb', line 2039

def match_results
  @match_results
end

#nameString

Identifier. The name of the discovered API Operation. Format: projects/ project/locations/location/discoveredApiObservations/ discovered_api_observation/discoveredApiOperations/discovered_api_operation` Corresponds to the JSON propertyname`

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/apihub_v1/classes.rb', line 2046

def name
  @name
end

#source_metadataGoogle::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata

SourceMetadata represents the metadata for a resource at the source. Corresponds to the JSON property sourceMetadata



2051
2052
2053
# File 'lib/google/apis/apihub_v1/classes.rb', line 2051

def 
  @source_metadata
end

#update_timeString

Output only. Update time stamp of the discovered API operation in API Hub. Corresponds to the JSON property updateTime

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/apihub_v1/classes.rb', line 2056

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
# File 'lib/google/apis/apihub_v1/classes.rb', line 2063

def update!(**args)
  @classification = args[:classification] if args.key?(:classification)
  @count = args[:count] if args.key?(:count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @first_seen_time = args[:first_seen_time] if args.key?(:first_seen_time)
  @http_operation = args[:http_operation] if args.key?(:http_operation)
  @last_seen_time = args[:last_seen_time] if args.key?(:last_seen_time)
  @match_results = args[:match_results] if args.key?(:match_results)
  @name = args[:name] if args.key?(:name)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end