Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The endpoint to be triggered for curation. The endpoint will be invoked with a request payload containing ApiMetadata. Response should contain curated data in the form of ApiMetadata.
Instance Attribute Summary collapse
-
#application_integration_endpoint_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApplicationIntegrationEndpointDetails
The details of the Application Integration endpoint to be triggered for curation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Endpoint
constructor
A new instance of GoogleCloudApihubV1Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Endpoint
Returns a new instance of GoogleCloudApihubV1Endpoint.
2140 2141 2142 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_integration_endpoint_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApplicationIntegrationEndpointDetails
The details of the Application Integration endpoint to be triggered for
curation.
Corresponds to the JSON property applicationIntegrationEndpointDetails
2138 2139 2140 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2138 def application_integration_endpoint_details @application_integration_endpoint_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2145 2146 2147 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2145 def update!(**args) @application_integration_endpoint_details = args[:application_integration_endpoint_details] if args.key?(:application_integration_endpoint_details) end |