Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The execution status for the plugin instance.
Instance Attribute Summary collapse
-
#current_execution_state ⇒ String
Output only.
-
#last_execution ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
The result of the last execution of the plugin instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ExecutionStatus
constructor
A new instance of GoogleCloudApihubV1ExecutionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ExecutionStatus
Returns a new instance of GoogleCloudApihubV1ExecutionStatus.
2230 2231 2232 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_execution_state ⇒ String
Output only. The current state of the execution.
Corresponds to the JSON property currentExecutionState
2223 2224 2225 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2223 def current_execution_state @current_execution_state end |
#last_execution ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
The result of the last execution of the plugin instance.
Corresponds to the JSON property lastExecution
2228 2229 2230 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2228 def last_execution @last_execution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2235 2236 2237 2238 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2235 def update!(**args) @current_execution_state = args[:current_execution_state] if args.key?(:current_execution_state) @last_execution = args[:last_execution] if args.key?(:last_execution) end |