Class: Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionDeploymentView
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionDeploymentView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A flattened view of an API, its version and one of the linked deployments.
Instance Attribute Summary collapse
-
#api ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Api
An API resource in the API Hub.
-
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted.
-
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionDeploymentView
constructor
A new instance of GoogleCloudApihubV1FlattenedApiVersionDeploymentView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionDeploymentView
Returns a new instance of GoogleCloudApihubV1FlattenedApiVersionDeploymentView.
2424 2425 2426 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Api
An API resource in the API Hub.
Corresponds to the JSON property api
2408 2409 2410 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2408 def api @api end |
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted. A deployment could represent
an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud
services as well. A deployment entity is a root level entity in the API hub
and exists independent of any API.
Corresponds to the JSON property deployment
2416 2417 2418 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2416 def deployment @deployment end |
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub. This is also referred to
as the API version.
Corresponds to the JSON property version
2422 2423 2424 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2422 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2429 2430 2431 2432 2433 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2429 def update!(**args) @api = args[:api] if args.key?(:api) @deployment = args[:deployment] if args.key?(:deployment) @version = args[:version] if args.key?(:version) end |