Class: Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionDeploymentView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

A flattened view of an API, its version and one of the linked deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionDeploymentView

Returns a new instance of GoogleCloudApihubV1FlattenedApiVersionDeploymentView.



2358
2359
2360
# File 'lib/google/apis/apihub_v1/classes.rb', line 2358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiGoogle::Apis::ApihubV1::GoogleCloudApihubV1Api

An API resource in the API Hub. Corresponds to the JSON property api



2342
2343
2344
# File 'lib/google/apis/apihub_v1/classes.rb', line 2342

def api
  @api
end

#deploymentGoogle::Apis::ApihubV1::GoogleCloudApihubV1Deployment

Details of the deployment where APIs are hosted. A deployment could represent an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud services as well. A deployment entity is a root level entity in the API hub and exists independent of any API. Corresponds to the JSON property deployment



2350
2351
2352
# File 'lib/google/apis/apihub_v1/classes.rb', line 2350

def deployment
  @deployment
end

#versionGoogle::Apis::ApihubV1::GoogleCloudApihubV1Version

Represents a version of the API resource in API hub. This is also referred to as the API version. Corresponds to the JSON property version



2356
2357
2358
# File 'lib/google/apis/apihub_v1/classes.rb', line 2356

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2363
2364
2365
2366
2367
# File 'lib/google/apis/apihub_v1/classes.rb', line 2363

def update!(**args)
  @api = args[:api] if args.key?(:api)
  @deployment = args[:deployment] if args.key?(:deployment)
  @version = args[:version] if args.key?(:version)
end