Class: Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A flattened view of an API, its version, one of its operations and one of the linked deployments. If there are no deployments linked to the operation then the result will be empty.
Instance Attribute Summary collapse
-
#api ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Api
An API resource in the API Hub.
-
#api_operation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApiOperation
Represents an operation contained in an API version in the API Hub.
-
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted.
-
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView
constructor
A new instance of GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView
Returns a new instance of GoogleCloudApihubV1FlattenedApiVersionOperationDeploymentView.
2407 2408 2409 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Api
An API resource in the API Hub.
Corresponds to the JSON property api
2379 2380 2381 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2379 def api @api end |
#api_operation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApiOperation
Represents an operation contained in an API version in the API Hub. An
operation is added/updated/deleted in an API version when a new spec is added
or an existing spec is updated/deleted in a version. Currently, an operation
will be created only corresponding to OpenAPI spec as parsing is supported for
OpenAPI spec. Alternatively operations can be managed via create,update and
delete APIs, creation of apiOperation can be possible only for version with no
parsed operations and update/delete can be possible only for operations
created via create API.
Corresponds to the JSON property apiOperation
2391 2392 2393 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2391 def api_operation @api_operation end |
#deployment ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Deployment
Details of the deployment where APIs are hosted. A deployment could represent
an Apigee proxy, API gateway, other Google Cloud services or non-Google Cloud
services as well. A deployment entity is a root level entity in the API hub
and exists independent of any API.
Corresponds to the JSON property deployment
2399 2400 2401 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2399 def deployment @deployment end |
#version ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Version
Represents a version of the API resource in API hub. This is also referred to
as the API version.
Corresponds to the JSON property version
2405 2406 2407 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2405 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2412 2413 2414 2415 2416 2417 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2412 def update!(**args) @api = args[:api] if args.key?(:api) @api_operation = args[:api_operation] if args.key?(:api_operation) @deployment = args[:deployment] if args.key?(:deployment) @version = args[:version] if args.key?(:version) end |