Class: Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1GatewayPluginConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Configuration for a gateway plugin. This is used to specify configs for different gateways.
Instance Attribute Summary collapse
-
#apigee_edge_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeEdgeConfig
Configuration for Apigee Edge gateways.
-
#apigee_opdk_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeOpdkConfig
Configuration for Apigee OPDK gateways.
-
#apigee_x_hybrid_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXHybridConfig
Configuration for Apigee X and Apigee Hybrid gateways.
-
#plugin_instance ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1GatewayPluginConfig
constructor
A new instance of GoogleCloudApihubV1GatewayPluginConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1GatewayPluginConfig
Returns a new instance of GoogleCloudApihubV1GatewayPluginConfig.
2477 2478 2479 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apigee_edge_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeEdgeConfig
Configuration for Apigee Edge gateways. Applicability of a filter is
determined by the filter being provided. If none of the filters are provided
the addon will be enabled for all data brought in by the gateway plugin
instance.
Corresponds to the JSON property apigeeEdgeConfig
2452 2453 2454 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2452 def apigee_edge_config @apigee_edge_config end |
#apigee_opdk_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeOpdkConfig
Configuration for Apigee OPDK gateways. Applicability of a filter is
determined by the filter being provided. If none of the filters are provided
the addon will be enabled for all data brought in by the gateway plugin
instance.
Corresponds to the JSON property apigeeOpdkConfig
2460 2461 2462 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2460 def apigee_opdk_config @apigee_opdk_config end |
#apigee_x_hybrid_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ApigeeXHybridConfig
Configuration for Apigee X and Apigee Hybrid gateways. Applicability of a
filter is determined by the filter being provided. If none of the filters are
provided the addon will be enabled for all data brought in by the gateway
plugin instance.
Corresponds to the JSON property apigeeXHybridConfig
2468 2469 2470 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2468 def apigee_x_hybrid_config @apigee_x_hybrid_config end |
#plugin_instance ⇒ String
Required. The name of the gateway plugin instance for which the config is to
be specified. Format: projects/project/locations/location/plugins/plugin/
pluginInstances/plugin_instance
Corresponds to the JSON property pluginInstance
2475 2476 2477 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2475 def plugin_instance @plugin_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2482 2483 2484 2485 2486 2487 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2482 def update!(**args) @apigee_edge_config = args[:apigee_edge_config] if args.key?(:apigee_edge_config) @apigee_opdk_config = args[:apigee_opdk_config] if args.key?(:apigee_opdk_config) @apigee_x_hybrid_config = args[:apigee_x_hybrid_config] if args.key?(:apigee_x_hybrid_config) @plugin_instance = args[:plugin_instance] if args.key?(:plugin_instance) end |