Class: Google::Apis::ApihubV1::GoogleCloudApihubV1GoogleServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Config for Google service account authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1GoogleServiceAccountConfig

Returns a new instance of GoogleCloudApihubV1GoogleServiceAccountConfig.



2501
2502
2503
# File 'lib/google/apis/apihub_v1/classes.rb', line 2501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Required. The service account to be used for authenticating request. The iam. serviceAccounts.getAccessToken permission should be granted on this service account to the impersonator service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2499
2500
2501
# File 'lib/google/apis/apihub_v1/classes.rb', line 2499

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2506
2507
2508
# File 'lib/google/apis/apihub_v1/classes.rb', line 2506

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
end