Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Header
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Header
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
An aggregation of HTTP header occurrences.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The number of occurrences of this Header across transactions.
-
#data_type ⇒ String
Data type of header Corresponds to the JSON property
dataType. -
#name ⇒ String
Header name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Header
constructor
A new instance of GoogleCloudApihubV1Header.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Header
Returns a new instance of GoogleCloudApihubV1Header.
2530 2531 2532 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The number of occurrences of this Header across transactions.
Corresponds to the JSON property count
2518 2519 2520 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2518 def count @count end |
#data_type ⇒ String
Data type of header
Corresponds to the JSON property dataType
2523 2524 2525 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2523 def data_type @data_type end |
#name ⇒ String
Header name.
Corresponds to the JSON property name
2528 2529 2530 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2528 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2535 2536 2537 2538 2539 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2535 def update!(**args) @count = args[:count] if args.key?(:count) @data_type = args[:data_type] if args.key?(:data_type) @name = args[:name] if args.key?(:name) end |