Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HostProjectRegistration
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1HostProjectRegistration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Host project registration refers to the registration of a Google cloud project with Api Hub as a host project. This is the project where Api Hub is provisioned. It acts as the consumer project for the Api Hub instance provisioned. Multiple runtime projects can be attached to the host project and these attachments define the scope of Api Hub.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#gcp_project ⇒ String
Required.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1HostProjectRegistration
constructor
A new instance of GoogleCloudApihubV1HostProjectRegistration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1HostProjectRegistration
Returns a new instance of GoogleCloudApihubV1HostProjectRegistration.
2635 2636 2637 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2635 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the host project registration was created.
Corresponds to the JSON property createTime
2619 2620 2621 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2619 def create_time @create_time end |
#gcp_project ⇒ String
Required. Immutable. Google cloud project name in the format: "projects/abc"
or "projects/123". As input, project name with either project id or number are
accepted. As output, this field will contain project number.
Corresponds to the JSON property gcpProject
2626 2627 2628 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2626 def gcp_project @gcp_project end |
#name ⇒ String
Identifier. The name of the host project registration. Format: "projects/
project/locations/location/hostProjectRegistrations/
host_project_registration".
Corresponds to the JSON property name
2633 2634 2635 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2633 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2640 2641 2642 2643 2644 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2640 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @gcp_project = args[:gcp_project] if args.key?(:gcp_project) @name = args[:name] if args.key?(:name) end |