Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HostProjectRegistration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Host project registration refers to the registration of a Google cloud project with Api Hub as a host project. This is the project where Api Hub is provisioned. It acts as the consumer project for the Api Hub instance provisioned. Multiple runtime projects can be attached to the host project and these attachments define the scope of Api Hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1HostProjectRegistration

Returns a new instance of GoogleCloudApihubV1HostProjectRegistration.



2569
2570
2571
# File 'lib/google/apis/apihub_v1/classes.rb', line 2569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the host project registration was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2553
2554
2555
# File 'lib/google/apis/apihub_v1/classes.rb', line 2553

def create_time
  @create_time
end

#gcp_projectString

Required. Immutable. Google cloud project name in the format: "projects/abc" or "projects/123". As input, project name with either project id or number are accepted. As output, this field will contain project number. Corresponds to the JSON property gcpProject

Returns:

  • (String)


2560
2561
2562
# File 'lib/google/apis/apihub_v1/classes.rb', line 2560

def gcp_project
  @gcp_project
end

#nameString

Identifier. The name of the host project registration. Format: "projects/ project/locations/location/hostProjectRegistrations/ host_project_registration". Corresponds to the JSON property name

Returns:

  • (String)


2567
2568
2569
# File 'lib/google/apis/apihub_v1/classes.rb', line 2567

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2574
2575
2576
2577
2578
# File 'lib/google/apis/apihub_v1/classes.rb', line 2574

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @gcp_project = args[:gcp_project] if args.key?(:gcp_project)
  @name = args[:name] if args.key?(:name)
end