Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The information related to the service implemented by the plugin developer, used to invoke the plugin's functionality.
Instance Attribute Summary collapse
-
#service_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1HostingService
constructor
A new instance of GoogleCloudApihubV1HostingService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1HostingService
Returns a new instance of GoogleCloudApihubV1HostingService.
2659 2660 2661 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service_uri ⇒ String
Optional. The URI of the service implemented by the plugin developer, used to
invoke the plugin's functionality. This information is only required for user
defined plugins.
Corresponds to the JSON property serviceUri
2657 2658 2659 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2657 def service_uri @service_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2664 2665 2666 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2664 def update!(**args) @service_uri = args[:service_uri] if args.key?(:service_uri) end |