Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HttpOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The HTTP Operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1HttpOperation

Returns a new instance of GoogleCloudApihubV1HttpOperation.



2619
2620
2621
# File 'lib/google/apis/apihub_v1/classes.rb', line 2619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#method_propString

Optional. Operation method Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided. Corresponds to the JSON property method

Returns:

  • (String)


2612
2613
2614
# File 'lib/google/apis/apihub_v1/classes.rb', line 2612

def method_prop
  @method_prop
end

#pathGoogle::Apis::ApihubV1::GoogleCloudApihubV1Path

The path details derived from the spec. Corresponds to the JSON property path



2617
2618
2619
# File 'lib/google/apis/apihub_v1/classes.rb', line 2617

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2624
2625
2626
2627
# File 'lib/google/apis/apihub_v1/classes.rb', line 2624

def update!(**args)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @path = args[:path] if args.key?(:path)
end