Class: Google::Apis::ApihubV1::GoogleCloudApihubV1HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An aggregation of HTTP responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1HttpResponse

Returns a new instance of GoogleCloudApihubV1HttpResponse.



2706
2707
2708
# File 'lib/google/apis/apihub_v1/classes.rb', line 2706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1Header>

Optional. Unordered map from header name to header metadata Corresponds to the JSON property headers



2699
2700
2701
# File 'lib/google/apis/apihub_v1/classes.rb', line 2699

def headers
  @headers
end

#response_codesHash<String,Fixnum>

Optional. Map of status code to observed count Corresponds to the JSON property responseCodes

Returns:

  • (Hash<String,Fixnum>)


2704
2705
2706
# File 'lib/google/apis/apihub_v1/classes.rb', line 2704

def response_codes
  @response_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2711
2712
2713
2714
# File 'lib/google/apis/apihub_v1/classes.rb', line 2711

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @response_codes = args[:response_codes] if args.key?(:response_codes)
end