Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Issue
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Issue contains the details of a single issue found by the linter.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#message ⇒ String
Required.
-
#path ⇒ Array<String>
Required.
-
#range ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Range
Object describing where in the file the issue was found.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Issue
constructor
A new instance of GoogleCloudApihubV1Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Issue
Returns a new instance of GoogleCloudApihubV1Issue.
2849 2850 2851 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. Rule code unique to each rule defined in linter.
Corresponds to the JSON property code
2826 2827 2828 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2826 def code @code end |
#message ⇒ String
Required. Human-readable message describing the issue found by the linter.
Corresponds to the JSON property message
2831 2832 2833 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2831 def @message end |
#path ⇒ Array<String>
Required. An array of strings indicating the location in the analyzed document
where the rule was triggered.
Corresponds to the JSON property path
2837 2838 2839 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2837 def path @path end |
#range ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Range
Object describing where in the file the issue was found.
Corresponds to the JSON property range
2842 2843 2844 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2842 def range @range end |
#severity ⇒ String
Required. Severity level of the rule violation.
Corresponds to the JSON property severity
2847 2848 2849 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2847 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2854 2855 2856 2857 2858 2859 2860 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2854 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @path = args[:path] if args.key?(:path) @range = args[:range] if args.key?(:range) @severity = args[:severity] if args.key?(:severity) end |