Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Issue
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Issue contains the details of a single issue found by the linter.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#message ⇒ String
Required.
-
#path ⇒ Array<String>
Required.
-
#range ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Range
Object describing where in the file the issue was found.
-
#severity ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Issue
constructor
A new instance of GoogleCloudApihubV1Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Issue
Returns a new instance of GoogleCloudApihubV1Issue.
2747 2748 2749 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. Rule code unique to each rule defined in linter.
Corresponds to the JSON property code
2724 2725 2726 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2724 def code @code end |
#message ⇒ String
Required. Human-readable message describing the issue found by the linter.
Corresponds to the JSON property message
2729 2730 2731 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2729 def @message end |
#path ⇒ Array<String>
Required. An array of strings indicating the location in the analyzed document
where the rule was triggered.
Corresponds to the JSON property path
2735 2736 2737 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2735 def path @path end |
#range ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Range
Object describing where in the file the issue was found.
Corresponds to the JSON property range
2740 2741 2742 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2740 def range @range end |
#severity ⇒ String
Required. Severity level of the rule violation.
Corresponds to the JSON property severity
2745 2746 2747 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2745 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2752 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @path = args[:path] if args.key?(:path) @range = args[:range] if args.key?(:range) @severity = args[:severity] if args.key?(:severity) end |