Class: Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The result of the last execution of the plugin instance.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Output only.
-
#error_message ⇒ String
Output only.
-
#result ⇒ String
Output only.
-
#result_metadata ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1LastExecution
constructor
A new instance of GoogleCloudApihubV1LastExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1LastExecution
Returns a new instance of GoogleCloudApihubV1LastExecution.
2895 2896 2897 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Output only. The last execution end time of the plugin instance.
Corresponds to the JSON property endTime
2870 2871 2872 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2870 def end_time @end_time end |
#error_message ⇒ String
Output only. Error message describing the failure, if any, during the last
execution.
Corresponds to the JSON property errorMessage
2876 2877 2878 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2876 def @error_message end |
#result ⇒ String
Output only. The result of the last execution of the plugin instance.
Corresponds to the JSON property result
2881 2882 2883 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2881 def result @result end |
#result_metadata ⇒ String
Output only. The result metadata of the last execution of the plugin instance.
This will be a string representation of a JSON object and will be available on
successful execution.
Corresponds to the JSON property resultMetadata
2888 2889 2890 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2888 def @result_metadata end |
#start_time ⇒ String
Output only. The last execution start time of the plugin instance.
Corresponds to the JSON property startTime
2893 2894 2895 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2893 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2900 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @error_message = args[:error_message] if args.key?(:error_message) @result = args[:result] if args.key?(:result) @result_metadata = args[:result_metadata] if args.key?(:result_metadata) @start_time = args[:start_time] if args.key?(:start_time) end |