Class: Google::Apis::ApihubV1::GoogleCloudApihubV1LastExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The result of the last execution of the plugin instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1LastExecution

Returns a new instance of GoogleCloudApihubV1LastExecution.



2793
2794
2795
# File 'lib/google/apis/apihub_v1/classes.rb', line 2793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. The last execution end time of the plugin instance. Corresponds to the JSON property endTime

Returns:

  • (String)


2768
2769
2770
# File 'lib/google/apis/apihub_v1/classes.rb', line 2768

def end_time
  @end_time
end

#error_messageString

Output only. Error message describing the failure, if any, during the last execution. Corresponds to the JSON property errorMessage

Returns:

  • (String)


2774
2775
2776
# File 'lib/google/apis/apihub_v1/classes.rb', line 2774

def error_message
  @error_message
end

#resultString

Output only. The result of the last execution of the plugin instance. Corresponds to the JSON property result

Returns:

  • (String)


2779
2780
2781
# File 'lib/google/apis/apihub_v1/classes.rb', line 2779

def result
  @result
end

#result_metadataString

Output only. The result metadata of the last execution of the plugin instance. This will be a string representation of a JSON object and will be available on successful execution. Corresponds to the JSON property resultMetadata

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/apihub_v1/classes.rb', line 2786

def 
  @result_metadata
end

#start_timeString

Output only. The last execution start time of the plugin instance. Corresponds to the JSON property startTime

Returns:

  • (String)


2791
2792
2793
# File 'lib/google/apis/apihub_v1/classes.rb', line 2791

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2798
2799
2800
2801
2802
2803
2804
# File 'lib/google/apis/apihub_v1/classes.rb', line 2798

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error_message = args[:error_message] if args.key?(:error_message)
  @result = args[:result] if args.key?(:result)
  @result_metadata = args[:result_metadata] if args.key?(:result_metadata)
  @start_time = args[:start_time] if args.key?(:start_time)
end