Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ListAddonsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1ListAddonsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The ListAddons method's response.
Instance Attribute Summary collapse
-
#addons ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1Addon>
The list of addons.
-
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more results in the list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1ListAddonsResponse
constructor
A new instance of GoogleCloudApihubV1ListAddonsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1ListAddonsResponse
Returns a new instance of GoogleCloudApihubV1ListAddonsResponse.
2884 2885 2886 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1Addon>
The list of addons.
Corresponds to the JSON property addons
2876 2877 2878 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2876 def addons @addons end |
#next_page_token ⇒ String
A token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
2882 2883 2884 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2882 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2889 2890 2891 2892 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 2889 def update!(**args) @addons = args[:addons] if args.key?(:addons) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |