Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Plugin
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Plugin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A plugin resource in the API Hub.
Instance Attribute Summary collapse
-
#actions_config ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig>
Optional.
-
#config_template ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigTemplate
ConfigTemplate represents the configuration template for a plugin.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#gateway_type ⇒ String
Optional.
-
#hosting_service ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
The information related to the service implemented by the plugin developer, used to invoke the plugin's functionality.
-
#name ⇒ String
Identifier.
-
#ownership_type ⇒ String
Output only.
-
#plugin_category ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Plugin
constructor
A new instance of GoogleCloudApihubV1Plugin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Plugin
Returns a new instance of GoogleCloudApihubV1Plugin.
4089 4090 4091 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_config ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig>
Optional. The configuration of actions supported by the plugin. REQUIRED:
This field must be provided when creating or updating a Plugin. The server
will reject requests if this field is missing.
Corresponds to the JSON property actionsConfig
4014 4015 4016 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4014 def actions_config @actions_config end |
#config_template ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigTemplate
ConfigTemplate represents the configuration template for a plugin.
Corresponds to the JSON property configTemplate
4019 4020 4021 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4019 def config_template @config_template end |
#create_time ⇒ String
Output only. Timestamp indicating when the plugin was created.
Corresponds to the JSON property createTime
4024 4025 4026 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4024 def create_time @create_time end |
#description ⇒ String
Optional. The plugin description. Max length is 2000 characters (Unicode code
points).
Corresponds to the JSON property description
4030 4031 4032 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4030 def description @description end |
#display_name ⇒ String
Required. The display name of the plugin. Max length is 50 characters (Unicode
code points).
Corresponds to the JSON property displayName
4036 4037 4038 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4036 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
4041 4042 4043 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4041 def documentation @documentation end |
#gateway_type ⇒ String
Optional. The type of the gateway.
Corresponds to the JSON property gatewayType
4046 4047 4048 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4046 def gateway_type @gateway_type end |
#hosting_service ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
The information related to the service implemented by the plugin developer,
used to invoke the plugin's functionality.
Corresponds to the JSON property hostingService
4052 4053 4054 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4052 def hosting_service @hosting_service end |
#name ⇒ String
Identifier. The name of the plugin. Format: projects/project/locations/
location/plugins/plugin`
Corresponds to the JSON propertyname`
4058 4059 4060 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4058 def name @name end |
#ownership_type ⇒ String
Output only. The type of the plugin, indicating whether it is 'SYSTEM_OWNED'
or 'USER_OWNED'.
Corresponds to the JSON property ownershipType
4064 4065 4066 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4064 def ownership_type @ownership_type end |
#plugin_category ⇒ String
Optional. The category of the plugin, identifying its primary category or
purpose. This field is required for all plugins.
Corresponds to the JSON property pluginCategory
4070 4071 4072 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4070 def plugin_category @plugin_category end |
#state ⇒ String
Output only. Represents the state of the plugin. Note this field will not be
set for plugins developed via plugin framework as the state will be managed at
plugin instance level.
Corresponds to the JSON property state
4077 4078 4079 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4077 def state @state end |
#type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property type
4082 4083 4084 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4082 def type @type end |
#update_time ⇒ String
Output only. Timestamp indicating when the plugin was last updated.
Corresponds to the JSON property updateTime
4087 4088 4089 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4087 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4094 def update!(**args) @actions_config = args[:actions_config] if args.key?(:actions_config) @config_template = args[:config_template] if args.key?(:config_template) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @gateway_type = args[:gateway_type] if args.key?(:gateway_type) @hosting_service = args[:hosting_service] if args.key?(:hosting_service) @name = args[:name] if args.key?(:name) @ownership_type = args[:ownership_type] if args.key?(:ownership_type) @plugin_category = args[:plugin_category] if args.key?(:plugin_category) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |