Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Plugin
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Plugin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
A plugin resource in the API Hub.
Instance Attribute Summary collapse
-
#actions_config ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig>
Optional.
-
#config_template ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigTemplate
ConfigTemplate represents the configuration template for a plugin.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#gateway_type ⇒ String
Optional.
-
#hosting_service ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
The information related to the service implemented by the plugin developer, used to invoke the plugin's functionality.
-
#name ⇒ String
Identifier.
-
#ownership_type ⇒ String
Output only.
-
#plugin_category ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Plugin
constructor
A new instance of GoogleCloudApihubV1Plugin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Plugin
Returns a new instance of GoogleCloudApihubV1Plugin.
3871 3872 3873 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_config ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig>
Optional. The configuration of actions supported by the plugin. REQUIRED:
This field must be provided when creating or updating a Plugin. The server
will reject requests if this field is missing.
Corresponds to the JSON property actionsConfig
3796 3797 3798 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3796 def actions_config @actions_config end |
#config_template ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigTemplate
ConfigTemplate represents the configuration template for a plugin.
Corresponds to the JSON property configTemplate
3801 3802 3803 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3801 def config_template @config_template end |
#create_time ⇒ String
Output only. Timestamp indicating when the plugin was created.
Corresponds to the JSON property createTime
3806 3807 3808 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3806 def create_time @create_time end |
#description ⇒ String
Optional. The plugin description. Max length is 2000 characters (Unicode code
points).
Corresponds to the JSON property description
3812 3813 3814 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3812 def description @description end |
#display_name ⇒ String
Required. The display name of the plugin. Max length is 50 characters (Unicode
code points).
Corresponds to the JSON property displayName
3818 3819 3820 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3818 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
3823 3824 3825 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3823 def documentation @documentation end |
#gateway_type ⇒ String
Optional. The type of the gateway.
Corresponds to the JSON property gatewayType
3828 3829 3830 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3828 def gateway_type @gateway_type end |
#hosting_service ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1HostingService
The information related to the service implemented by the plugin developer,
used to invoke the plugin's functionality.
Corresponds to the JSON property hostingService
3834 3835 3836 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3834 def hosting_service @hosting_service end |
#name ⇒ String
Identifier. The name of the plugin. Format: projects/project/locations/
location/plugins/plugin`
Corresponds to the JSON propertyname`
3840 3841 3842 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3840 def name @name end |
#ownership_type ⇒ String
Output only. The type of the plugin, indicating whether it is 'SYSTEM_OWNED'
or 'USER_OWNED'.
Corresponds to the JSON property ownershipType
3846 3847 3848 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3846 def ownership_type @ownership_type end |
#plugin_category ⇒ String
Optional. The category of the plugin, identifying its primary category or
purpose. This field is required for all plugins.
Corresponds to the JSON property pluginCategory
3852 3853 3854 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3852 def plugin_category @plugin_category end |
#state ⇒ String
Output only. Represents the state of the plugin. Note this field will not be
set for plugins developed via plugin framework as the state will be managed at
plugin instance level.
Corresponds to the JSON property state
3859 3860 3861 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3859 def state @state end |
#type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property type
3864 3865 3866 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3864 def type @type end |
#update_time ⇒ String
Output only. Timestamp indicating when the plugin was last updated.
Corresponds to the JSON property updateTime
3869 3870 3871 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3869 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3876 def update!(**args) @actions_config = args[:actions_config] if args.key?(:actions_config) @config_template = args[:config_template] if args.key?(:config_template) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @gateway_type = args[:gateway_type] if args.key?(:gateway_type) @hosting_service = args[:hosting_service] if args.key?(:hosting_service) @name = args[:name] if args.key?(:name) @ownership_type = args[:ownership_type] if args.key?(:ownership_type) @plugin_category = args[:plugin_category] if args.key?(:plugin_category) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |