Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1PluginActionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
PluginActionConfig represents the configuration of an action supported by a plugin.
Instance Attribute Summary collapse
-
#description ⇒ String
Required.
-
#display_name ⇒ String
Required.
-
#id ⇒ String
Required.
-
#trigger_mode ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1PluginActionConfig
constructor
A new instance of GoogleCloudApihubV1PluginActionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1PluginActionConfig
Returns a new instance of GoogleCloudApihubV1PluginActionConfig.
3919 3920 3921 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Required. The description of the operation performed by the action.
Corresponds to the JSON property description
3902 3903 3904 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3902 def description @description end |
#display_name ⇒ String
Required. The display name of the action.
Corresponds to the JSON property displayName
3907 3908 3909 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3907 def display_name @display_name end |
#id ⇒ String
Required. The id of the action.
Corresponds to the JSON property id
3912 3913 3914 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3912 def id @id end |
#trigger_mode ⇒ String
Required. The trigger mode supported by the action.
Corresponds to the JSON property triggerMode
3917 3918 3919 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3917 def trigger_mode @trigger_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3924 3925 3926 3927 3928 3929 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 3924 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @trigger_mode = args[:trigger_mode] if args.key?(:trigger_mode) end |