Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstance
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents a plugin instance resource in the API Hub. A PluginInstance is a specific instance of a hub plugin with its own configuration, state, and execution details.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction>
Required.
-
#additional_config ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable>
Optional.
-
#auth_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AuthConfig
AuthConfig represents the authentication information.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#error_message ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#source_environments_config ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment>
Optional.
-
#source_project_id ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstance
constructor
A new instance of GoogleCloudApihubV1PluginInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstance
Returns a new instance of GoogleCloudApihubV1PluginInstance.
4226 4227 4228 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction>
Required. The action status for the plugin instance.
Corresponds to the JSON property actions
4159 4160 4161 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4159 def actions @actions end |
#additional_config ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable>
Optional. The additional information for this plugin instance corresponding to
the additional config template of the plugin. This information will be sent to
plugin hosting service on each call to plugin hosted service. The key will be
the config_variable_template.display_name to uniquely identify the config
variable.
Corresponds to the JSON property additionalConfig
4168 4169 4170 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4168 def additional_config @additional_config end |
#auth_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AuthConfig
AuthConfig represents the authentication information.
Corresponds to the JSON property authConfig
4173 4174 4175 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4173 def auth_config @auth_config end |
#create_time ⇒ String
Output only. Timestamp indicating when the plugin instance was created.
Corresponds to the JSON property createTime
4178 4179 4180 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4178 def create_time @create_time end |
#display_name ⇒ String
Required. The display name for this plugin instance. Max length is 255
characters.
Corresponds to the JSON property displayName
4184 4185 4186 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4184 def display_name @display_name end |
#error_message ⇒ String
Output only. Error message describing the failure, if any, during Create,
Delete or ApplyConfig operation corresponding to the plugin instance.This
field will only be populated if the plugin instance is in the ERROR or FAILED
state.
Corresponds to the JSON property errorMessage
4192 4193 4194 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4192 def @error_message end |
#name ⇒ String
Identifier. The unique name of the plugin instance resource. Format: projects/
project/locations/location/plugins/plugin/instances/instance`
Corresponds to the JSON propertyname`
4198 4199 4200 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4198 def name @name end |
#source_environments_config ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment>
Optional. The source environment's config present in the gateway instance
linked to the plugin instance. The key is the source_environment name from
the SourceEnvironment message.
Corresponds to the JSON property sourceEnvironmentsConfig
4205 4206 4207 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4205 def source_environments_config @source_environments_config end |
#source_project_id ⇒ String
Optional. The source project id of the plugin instance. This will be the id of
runtime project in case of Google Cloud based plugins and org id in case of
non-Google Cloud based plugins. This field will be a required field for Google
provided on-ramp plugins.
Corresponds to the JSON property sourceProjectId
4213 4214 4215 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4213 def source_project_id @source_project_id end |
#state ⇒ String
Output only. The current state of the plugin instance (e.g., enabled, disabled,
provisioning).
Corresponds to the JSON property state
4219 4220 4221 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4219 def state @state end |
#update_time ⇒ String
Output only. Timestamp indicating when the plugin instance was last updated.
Corresponds to the JSON property updateTime
4224 4225 4226 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4224 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4231 4232 4233 4234 4235 4236 4237 4238 4239 4240 4241 4242 4243 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4231 def update!(**args) @actions = args[:actions] if args.key?(:actions) @additional_config = args[:additional_config] if args.key?(:additional_config) @auth_config = args[:auth_config] if args.key?(:auth_config) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error_message = args[:error_message] if args.key?(:error_message) @name = args[:name] if args.key?(:name) @source_environments_config = args[:source_environments_config] if args.key?(:source_environments_config) @source_project_id = args[:source_project_id] if args.key?(:source_project_id) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |