Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Represents a plugin instance resource in the API Hub. A PluginInstance is a specific instance of a hub plugin with its own configuration, state, and execution details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstance

Returns a new instance of GoogleCloudApihubV1PluginInstance.



4008
4009
4010
# File 'lib/google/apis/apihub_v1/classes.rb', line 4008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction>

Required. The action status for the plugin instance. Corresponds to the JSON property actions



3941
3942
3943
# File 'lib/google/apis/apihub_v1/classes.rb', line 3941

def actions
  @actions
end

#additional_configHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1ConfigVariable>

Optional. The additional information for this plugin instance corresponding to the additional config template of the plugin. This information will be sent to plugin hosting service on each call to plugin hosted service. The key will be the config_variable_template.display_name to uniquely identify the config variable. Corresponds to the JSON property additionalConfig



3950
3951
3952
# File 'lib/google/apis/apihub_v1/classes.rb', line 3950

def additional_config
  @additional_config
end

#auth_configGoogle::Apis::ApihubV1::GoogleCloudApihubV1AuthConfig

AuthConfig represents the authentication information. Corresponds to the JSON property authConfig



3955
3956
3957
# File 'lib/google/apis/apihub_v1/classes.rb', line 3955

def auth_config
  @auth_config
end

#create_timeString

Output only. Timestamp indicating when the plugin instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/apihub_v1/classes.rb', line 3960

def create_time
  @create_time
end

#display_nameString

Required. The display name for this plugin instance. Max length is 255 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3966
3967
3968
# File 'lib/google/apis/apihub_v1/classes.rb', line 3966

def display_name
  @display_name
end

#error_messageString

Output only. Error message describing the failure, if any, during Create, Delete or ApplyConfig operation corresponding to the plugin instance.This field will only be populated if the plugin instance is in the ERROR or FAILED state. Corresponds to the JSON property errorMessage

Returns:

  • (String)


3974
3975
3976
# File 'lib/google/apis/apihub_v1/classes.rb', line 3974

def error_message
  @error_message
end

#nameString

Identifier. The unique name of the plugin instance resource. Format: projects/ project/locations/location/plugins/plugin/instances/instance` Corresponds to the JSON propertyname`

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/apihub_v1/classes.rb', line 3980

def name
  @name
end

#source_environments_configHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment>

Optional. The source environment's config present in the gateway instance linked to the plugin instance. The key is the source_environment name from the SourceEnvironment message. Corresponds to the JSON property sourceEnvironmentsConfig



3987
3988
3989
# File 'lib/google/apis/apihub_v1/classes.rb', line 3987

def source_environments_config
  @source_environments_config
end

#source_project_idString

Optional. The source project id of the plugin instance. This will be the id of runtime project in case of Google Cloud based plugins and org id in case of non-Google Cloud based plugins. This field will be a required field for Google provided on-ramp plugins. Corresponds to the JSON property sourceProjectId

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/apihub_v1/classes.rb', line 3995

def source_project_id
  @source_project_id
end

#stateString

Output only. The current state of the plugin instance (e.g., enabled, disabled, provisioning). Corresponds to the JSON property state

Returns:

  • (String)


4001
4002
4003
# File 'lib/google/apis/apihub_v1/classes.rb', line 4001

def state
  @state
end

#update_timeString

Output only. Timestamp indicating when the plugin instance was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4006
4007
4008
# File 'lib/google/apis/apihub_v1/classes.rb', line 4006

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
# File 'lib/google/apis/apihub_v1/classes.rb', line 4013

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @additional_config = args[:additional_config] if args.key?(:additional_config)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error_message = args[:error_message] if args.key?(:error_message)
  @name = args[:name] if args.key?(:name)
  @source_environments_config = args[:source_environments_config] if args.key?(:source_environments_config)
  @source_project_id = args[:source_project_id] if args.key?(:source_project_id)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end