Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
PluginInstanceAction represents an action which can be executed in the plugin instance.
Instance Attribute Summary collapse
-
#action_id ⇒ String
Required.
-
#curation_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1CurationConfig
The curation information for this plugin instance.
-
#hub_instance_action ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
The execution status for the plugin instance.
-
#resource_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ResourceConfig
The configuration of resources created for a given plugin instance action.
-
#schedule_cron_expression ⇒ String
Optional.
-
#schedule_time_zone ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstanceAction
constructor
A new instance of GoogleCloudApihubV1PluginInstanceAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstanceAction
Returns a new instance of GoogleCloudApihubV1PluginInstanceAction.
4295 4296 4297 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4295 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_id ⇒ String
Required. This should map to one of the action id specified in actions_config
in the plugin.
Corresponds to the JSON property actionId
4255 4256 4257 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4255 def action_id @action_id end |
#curation_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1CurationConfig
The curation information for this plugin instance.
Corresponds to the JSON property curationConfig
4260 4261 4262 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4260 def curation_config @curation_config end |
#hub_instance_action ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
The execution status for the plugin instance.
Corresponds to the JSON property hubInstanceAction
4265 4266 4267 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4265 def hub_instance_action @hub_instance_action end |
#resource_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ResourceConfig
The configuration of resources created for a given plugin instance action.
Corresponds to the JSON property resourceConfig
4270 4271 4272 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4270 def resource_config @resource_config end |
#schedule_cron_expression ⇒ String
Optional. The schedule for this plugin instance action. This can only be set
if the plugin supports API_HUB_SCHEDULE_TRIGGER mode for this action.
Corresponds to the JSON property scheduleCronExpression
4276 4277 4278 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4276 def schedule_cron_expression @schedule_cron_expression end |
#schedule_time_zone ⇒ String
Optional. The time zone for the schedule cron expression. If not provided, UTC
will be used.
Corresponds to the JSON property scheduleTimeZone
4282 4283 4284 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4282 def schedule_time_zone @schedule_time_zone end |
#service_account ⇒ String
Optional. The service account used to publish data. Note, the service account
will only be accepted for non-Google Cloud plugins like OPDK.
Corresponds to the JSON property serviceAccount
4288 4289 4290 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4288 def service_account @service_account end |
#state ⇒ String
Output only. The current state of the plugin action in the plugin instance.
Corresponds to the JSON property state
4293 4294 4295 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4293 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4300 def update!(**args) @action_id = args[:action_id] if args.key?(:action_id) @curation_config = args[:curation_config] if args.key?(:curation_config) @hub_instance_action = args[:hub_instance_action] if args.key?(:hub_instance_action) @resource_config = args[:resource_config] if args.key?(:resource_config) @schedule_cron_expression = args[:schedule_cron_expression] if args.key?(:schedule_cron_expression) @schedule_time_zone = args[:schedule_time_zone] if args.key?(:schedule_time_zone) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) end |