Class: Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1PluginInstanceAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
PluginInstanceAction represents an action which can be executed in the plugin instance.
Instance Attribute Summary collapse
-
#action_id ⇒ String
Required.
-
#curation_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1CurationConfig
The curation information for this plugin instance.
-
#hub_instance_action ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
The execution status for the plugin instance.
-
#resource_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ResourceConfig
The configuration of resources created for a given plugin instance action.
-
#schedule_cron_expression ⇒ String
Optional.
-
#schedule_time_zone ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstanceAction
constructor
A new instance of GoogleCloudApihubV1PluginInstanceAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1PluginInstanceAction
Returns a new instance of GoogleCloudApihubV1PluginInstanceAction.
4077 4078 4079 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_id ⇒ String
Required. This should map to one of the action id specified in actions_config
in the plugin.
Corresponds to the JSON property actionId
4037 4038 4039 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4037 def action_id @action_id end |
#curation_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1CurationConfig
The curation information for this plugin instance.
Corresponds to the JSON property curationConfig
4042 4043 4044 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4042 def curation_config @curation_config end |
#hub_instance_action ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ExecutionStatus
The execution status for the plugin instance.
Corresponds to the JSON property hubInstanceAction
4047 4048 4049 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4047 def hub_instance_action @hub_instance_action end |
#resource_config ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1ResourceConfig
The configuration of resources created for a given plugin instance action.
Corresponds to the JSON property resourceConfig
4052 4053 4054 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4052 def resource_config @resource_config end |
#schedule_cron_expression ⇒ String
Optional. The schedule for this plugin instance action. This can only be set
if the plugin supports API_HUB_SCHEDULE_TRIGGER mode for this action.
Corresponds to the JSON property scheduleCronExpression
4058 4059 4060 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4058 def schedule_cron_expression @schedule_cron_expression end |
#schedule_time_zone ⇒ String
Optional. The time zone for the schedule cron expression. If not provided, UTC
will be used.
Corresponds to the JSON property scheduleTimeZone
4064 4065 4066 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4064 def schedule_time_zone @schedule_time_zone end |
#service_account ⇒ String
Optional. The service account used to publish data. Note, the service account
will only be accepted for non-Google Cloud plugins like OPDK.
Corresponds to the JSON property serviceAccount
4070 4071 4072 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4070 def service_account @service_account end |
#state ⇒ String
Output only. The current state of the plugin action in the plugin instance.
Corresponds to the JSON property state
4075 4076 4077 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4075 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4082 def update!(**args) @action_id = args[:action_id] if args.key?(:action_id) @curation_config = args[:curation_config] if args.key?(:curation_config) @hub_instance_action = args[:hub_instance_action] if args.key?(:hub_instance_action) @resource_config = args[:resource_config] if args.key?(:resource_config) @schedule_cron_expression = args[:schedule_cron_expression] if args.key?(:schedule_cron_expression) @schedule_time_zone = args[:schedule_time_zone] if args.key?(:schedule_time_zone) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) end |