Class: Google::Apis::ApihubV1::GoogleCloudApihubV1QueryParam

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

An aggregation of HTTP query parameter occurrences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1QueryParam

Returns a new instance of GoogleCloudApihubV1QueryParam.



4192
4193
4194
# File 'lib/google/apis/apihub_v1/classes.rb', line 4192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Optional. The number of occurrences of this query parameter across transactions. Corresponds to the JSON property count

Returns:

  • (Fixnum)


4180
4181
4182
# File 'lib/google/apis/apihub_v1/classes.rb', line 4180

def count
  @count
end

#data_typeString

Optional. Data type of path param Corresponds to the JSON property dataType

Returns:

  • (String)


4185
4186
4187
# File 'lib/google/apis/apihub_v1/classes.rb', line 4185

def data_type
  @data_type
end

#nameString

Required. Name of query param Corresponds to the JSON property name

Returns:

  • (String)


4190
4191
4192
# File 'lib/google/apis/apihub_v1/classes.rb', line 4190

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4197
4198
4199
4200
4201
# File 'lib/google/apis/apihub_v1/classes.rb', line 4197

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @data_type = args[:data_type] if args.key?(:data_type)
  @name = args[:name] if args.key?(:name)
end