Class: Google::Apis::ApihubV1::GoogleCloudApihubV1RuntimeProjectAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Runtime project attachment represents an attachment from the runtime project to the host project. Api Hub looks for deployments in the attached runtime projects and creates corresponding resources in Api Hub for the discovered deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1RuntimeProjectAttachment

Returns a new instance of GoogleCloudApihubV1RuntimeProjectAttachment.



4306
4307
4308
# File 'lib/google/apis/apihub_v1/classes.rb', line 4306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


4290
4291
4292
# File 'lib/google/apis/apihub_v1/classes.rb', line 4290

def create_time
  @create_time
end

#nameString

Identifier. The resource name of a runtime project attachment. Format: " projects/project/locations/location/runtimeProjectAttachments/ runtime_project_attachment". Corresponds to the JSON property name

Returns:

  • (String)


4297
4298
4299
# File 'lib/google/apis/apihub_v1/classes.rb', line 4297

def name
  @name
end

#runtime_projectString

Required. Immutable. Google cloud project name in the format: "projects/abc" or "projects/123". As input, project name with either project id or number are accepted. As output, this field will contain project number. Corresponds to the JSON property runtimeProject

Returns:

  • (String)


4304
4305
4306
# File 'lib/google/apis/apihub_v1/classes.rb', line 4304

def runtime_project
  @runtime_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4311
4312
4313
4314
4315
# File 'lib/google/apis/apihub_v1/classes.rb', line 4311

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @runtime_project = args[:runtime_project] if args.key?(:runtime_project)
end