Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The schema details derived from the spec. Currently, this entity is supported
for OpenAPI spec only. For OpenAPI spec, this maps to the schema defined in
the definitions section for OpenAPI 2.0 version and in components.schemas
section for OpenAPI 3.0 and 3.1 version.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#raw_value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Schema
constructor
A new instance of GoogleCloudApihubV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Schema
Returns a new instance of GoogleCloudApihubV1Schema.
4338 4339 4340 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name of the schema. This will map to the name of the
schema in the spec.
Corresponds to the JSON property displayName
4329 4330 4331 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4329 def display_name @display_name end |
#raw_value ⇒ String
Output only. The raw value of the schema definition corresponding to the
schema name in the spec.
Corresponds to the JSON property rawValue
NOTE: Values are automatically base64 encoded/decoded in the client library.
4336 4337 4338 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4336 def raw_value @raw_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4343 4344 4345 4346 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4343 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @raw_value = args[:raw_value] if args.key?(:raw_value) end |