Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResourcesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The SearchResources method's request.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResourcesRequest
constructor
A new instance of GoogleCloudApihubV1SearchResourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResourcesRequest
Returns a new instance of GoogleCloudApihubV1SearchResourcesRequest.
4611 4612 4613 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. An expression that filters the list of search results. A filter
expression consists of a field name, a comparison operator, and a value for
filtering. The value must be a string, a number, or a boolean. The comparison
operator must be =. Filters are not case sensitive. The following field
names are eligible for filtering: * resource_type - The type of resource in
the search results. Must be one of the following: Api, ApiOperation,
Deployment, Definition, Spec or Version. This field can only be
specified once in the filter. Here are is an example: * resource_type = Api -
The resource_type is Api.
Corresponds to the JSON property filter
4582 4583 4584 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4582 def filter @filter end |
#page_size ⇒ Fixnum
Optional. The maximum number of search results to return. The service may
return fewer than this value. If unspecified at most 10 search results will be
returned. If value is negative then INVALID_ARGUMENT error is returned. The
maximum value is 25; values above 25 will be coerced to 25. While paginating,
you can specify a new page size parameter for each page of search results to
be listed.
Corresponds to the JSON property pageSize
4592 4593 4594 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4592 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous SearchResources call. Specify
this parameter to retrieve the next page of transactions. When paginating, you
must specify the page_token parameter and all the other parameters except
page_size should be specified with the same value which was used in the
previous call. If the other fields are set with a different value than the
previous call then INVALID_ARGUMENT error is returned.
Corresponds to the JSON property pageToken
4602 4603 4604 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4602 def page_token @page_token end |
#query ⇒ String
Required. The free text search query. This query can contain keywords which
could be related to any detail of the API-Hub resources such display names,
descriptions, attributes etc.
Corresponds to the JSON property query
4609 4610 4611 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4609 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4616 4617 4618 4619 4620 4621 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4616 def update!(**args) @filter = args[:filter] if args.key?(:filter) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) end |