Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResourcesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Response for the SearchResources method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pass this token in the SearchResourcesRequest to continue to list results.
-
#search_results ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResult>
List of search results according to the filter and search query specified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResourcesResponse
constructor
A new instance of GoogleCloudApihubV1SearchResourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1SearchResourcesResponse
Returns a new instance of GoogleCloudApihubV1SearchResourcesResponse.
4641 4642 4643 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pass this token in the SearchResourcesRequest to continue to list results. If
all results have been returned, this field is an empty string or not present
in the response.
Corresponds to the JSON property nextPageToken
4633 4634 4635 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4633 def next_page_token @next_page_token end |
#search_results ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SearchResult>
List of search results according to the filter and search query specified. The
order of search results represents the ranking.
Corresponds to the JSON property searchResults
4639 4640 4641 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4639 def search_results @search_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4646 4647 4648 4649 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4646 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @search_results = args[:search_results] if args.key?(:search_results) end |