Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Message representing the source environment details.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Optional.
-
#source_environment ⇒ String
Required.
-
#source_environment_uri ⇒ String
The location where additional information about source environments can be found.
-
#update_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1SourceEnvironment
constructor
A new instance of GoogleCloudApihubV1SourceEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1SourceEnvironment
Returns a new instance of GoogleCloudApihubV1SourceEnvironment.
4719 4720 4721 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Optional. The time at which the environment was created at the source.
Corresponds to the JSON property createTime
4699 4700 4701 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4699 def create_time @create_time end |
#source_environment ⇒ String
Required. The name of the environment at the source. This should map to
Deployment.
Corresponds to the JSON property sourceEnvironment
4705 4706 4707 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4705 def source_environment @source_environment end |
#source_environment_uri ⇒ String
The location where additional information about source environments can be
found. The location should be relative path of the environment manifest with
respect to a plugin instance.
Corresponds to the JSON property sourceEnvironmentUri
4712 4713 4714 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4712 def source_environment_uri @source_environment_uri end |
#update_time ⇒ String
Optional. The time at which the environment was last updated at the source.
Corresponds to the JSON property updateTime
4717 4718 4719 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4717 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4724 4725 4726 4727 4728 4729 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4724 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @source_environment = args[:source_environment] if args.key?(:source_environment) @source_environment_uri = args[:source_environment_uri] if args.key?(:source_environment_uri) @update_time = args[:update_time] if args.key?(:update_time) end |