Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SourceEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Message representing the source environment details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1SourceEnvironment

Returns a new instance of GoogleCloudApihubV1SourceEnvironment.



4501
4502
4503
# File 'lib/google/apis/apihub_v1/classes.rb', line 4501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Optional. The time at which the environment was created at the source. Corresponds to the JSON property createTime

Returns:

  • (String)


4481
4482
4483
# File 'lib/google/apis/apihub_v1/classes.rb', line 4481

def create_time
  @create_time
end

#source_environmentString

Required. The name of the environment at the source. This should map to Deployment. Corresponds to the JSON property sourceEnvironment

Returns:

  • (String)


4487
4488
4489
# File 'lib/google/apis/apihub_v1/classes.rb', line 4487

def source_environment
  @source_environment
end

#source_environment_uriString

The location where additional information about source environments can be found. The location should be relative path of the environment manifest with respect to a plugin instance. Corresponds to the JSON property sourceEnvironmentUri

Returns:

  • (String)


4494
4495
4496
# File 'lib/google/apis/apihub_v1/classes.rb', line 4494

def source_environment_uri
  @source_environment_uri
end

#update_timeString

Optional. The time at which the environment was last updated at the source. Corresponds to the JSON property updateTime

Returns:

  • (String)


4499
4500
4501
# File 'lib/google/apis/apihub_v1/classes.rb', line 4499

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4506
4507
4508
4509
4510
4511
# File 'lib/google/apis/apihub_v1/classes.rb', line 4506

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @source_environment = args[:source_environment] if args.key?(:source_environment)
  @source_environment_uri = args[:source_environment_uri] if args.key?(:source_environment_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end