Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Spec
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Spec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently.
Instance Attribute Summary collapse
-
#additional_spec_contents ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1AdditionalSpecContent>
Output only.
-
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional.
-
#contents ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecContents
The spec contents.
-
#create_time ⇒ String
Output only.
-
#details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails
SpecDetails contains the details parsed from supported spec types.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#lint_response ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LintResponse
LintResponse contains the response from the linter.
-
#name ⇒ String
Identifier.
-
#parsing_mode ⇒ String
Optional.
-
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only.
-
#source_uri ⇒ String
Optional.
-
#spec_type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Spec
constructor
A new instance of GoogleCloudApihubV1Spec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Spec
Returns a new instance of GoogleCloudApihubV1Spec.
4858 4859 4860 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_spec_contents ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1AdditionalSpecContent>
Output only. The additional spec contents for the spec.
Corresponds to the JSON property additionalSpecContents
4784 4785 4786 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4784 def additional_spec_contents @additional_spec_contents end |
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional. The list of user defined attributes associated with the spec. The
key is the attribute name. It will be of the format: projects/project/
locations/location/attributes/attribute`. The value is the attribute
values associated with the resource.
Corresponds to the JSON propertyattributes`
4792 4793 4794 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4792 def attributes @attributes end |
#contents ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecContents
The spec contents.
Corresponds to the JSON property contents
4797 4798 4799 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4797 def contents @contents end |
#create_time ⇒ String
Output only. The time at which the spec was created.
Corresponds to the JSON property createTime
4802 4803 4804 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4802 def create_time @create_time end |
#details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails
SpecDetails contains the details parsed from supported spec types.
Corresponds to the JSON property details
4807 4808 4809 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4807 def details @details end |
#display_name ⇒ String
Required. The display name of the spec. This can contain the file name of the
spec.
Corresponds to the JSON property displayName
4813 4814 4815 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4813 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
4818 4819 4820 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4818 def documentation @documentation end |
#lint_response ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1LintResponse
LintResponse contains the response from the linter.
Corresponds to the JSON property lintResponse
4823 4824 4825 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4823 def lint_response @lint_response end |
#name ⇒ String
Identifier. The name of the spec. Format: projects/project/locations/
location/apis/api/versions/version/specs/spec`
Corresponds to the JSON propertyname`
4829 4830 4831 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4829 def name @name end |
#parsing_mode ⇒ String
Optional. Input only. Enum specifying the parsing mode for OpenAPI
Specification (OAS) parsing.
Corresponds to the JSON property parsingMode
4835 4836 4837 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4835 def parsing_mode @parsing_mode end |
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only. The list of sources and metadata from the sources of the spec.
Corresponds to the JSON property sourceMetadata
4840 4841 4842 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4840 def @source_metadata end |
#source_uri ⇒ String
Optional. The URI of the spec source in case file is uploaded from an external
version control system.
Corresponds to the JSON property sourceUri
4846 4847 4848 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4846 def source_uri @source_uri end |
#spec_type ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property specType
4851 4852 4853 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4851 def spec_type @spec_type end |
#update_time ⇒ String
Output only. The time at which the spec was last updated.
Corresponds to the JSON property updateTime
4856 4857 4858 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4856 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 4876 4877 4878 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4863 def update!(**args) @additional_spec_contents = args[:additional_spec_contents] if args.key?(:additional_spec_contents) @attributes = args[:attributes] if args.key?(:attributes) @contents = args[:contents] if args.key?(:contents) @create_time = args[:create_time] if args.key?(:create_time) @details = args[:details] if args.key?(:details) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @lint_response = args[:lint_response] if args.key?(:lint_response) @name = args[:name] if args.key?(:name) @parsing_mode = args[:parsing_mode] if args.key?(:parsing_mode) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @source_uri = args[:source_uri] if args.key?(:source_uri) @spec_type = args[:spec_type] if args.key?(:spec_type) @update_time = args[:update_time] if args.key?(:update_time) end |