Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Spec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1Spec

Returns a new instance of GoogleCloudApihubV1Spec.



4640
4641
4642
# File 'lib/google/apis/apihub_v1/classes.rb', line 4640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_spec_contentsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1AdditionalSpecContent>

Output only. The additional spec contents for the spec. Corresponds to the JSON property additionalSpecContents



4566
4567
4568
# File 'lib/google/apis/apihub_v1/classes.rb', line 4566

def additional_spec_contents
  @additional_spec_contents
end

#attributesHash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>

Optional. The list of user defined attributes associated with the spec. The key is the attribute name. It will be of the format: projects/project/ locations/location/attributes/attribute`. The value is the attribute values associated with the resource. Corresponds to the JSON propertyattributes`



4574
4575
4576
# File 'lib/google/apis/apihub_v1/classes.rb', line 4574

def attributes
  @attributes
end

#contentsGoogle::Apis::ApihubV1::GoogleCloudApihubV1SpecContents

The spec contents. Corresponds to the JSON property contents



4579
4580
4581
# File 'lib/google/apis/apihub_v1/classes.rb', line 4579

def contents
  @contents
end

#create_timeString

Output only. The time at which the spec was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4584
4585
4586
# File 'lib/google/apis/apihub_v1/classes.rb', line 4584

def create_time
  @create_time
end

#detailsGoogle::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails

SpecDetails contains the details parsed from supported spec types. Corresponds to the JSON property details



4589
4590
4591
# File 'lib/google/apis/apihub_v1/classes.rb', line 4589

def details
  @details
end

#display_nameString

Required. The display name of the spec. This can contain the file name of the spec. Corresponds to the JSON property displayName

Returns:

  • (String)


4595
4596
4597
# File 'lib/google/apis/apihub_v1/classes.rb', line 4595

def display_name
  @display_name
end

#documentationGoogle::Apis::ApihubV1::GoogleCloudApihubV1Documentation

Documentation details. Corresponds to the JSON property documentation



4600
4601
4602
# File 'lib/google/apis/apihub_v1/classes.rb', line 4600

def documentation
  @documentation
end

#lint_responseGoogle::Apis::ApihubV1::GoogleCloudApihubV1LintResponse

LintResponse contains the response from the linter. Corresponds to the JSON property lintResponse



4605
4606
4607
# File 'lib/google/apis/apihub_v1/classes.rb', line 4605

def lint_response
  @lint_response
end

#nameString

Identifier. The name of the spec. Format: projects/project/locations/ location/apis/api/versions/version/specs/spec` Corresponds to the JSON propertyname`

Returns:

  • (String)


4611
4612
4613
# File 'lib/google/apis/apihub_v1/classes.rb', line 4611

def name
  @name
end

#parsing_modeString

Optional. Input only. Enum specifying the parsing mode for OpenAPI Specification (OAS) parsing. Corresponds to the JSON property parsingMode

Returns:

  • (String)


4617
4618
4619
# File 'lib/google/apis/apihub_v1/classes.rb', line 4617

def parsing_mode
  @parsing_mode
end

#source_metadataArray<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>

Output only. The list of sources and metadata from the sources of the spec. Corresponds to the JSON property sourceMetadata



4622
4623
4624
# File 'lib/google/apis/apihub_v1/classes.rb', line 4622

def 
  @source_metadata
end

#source_uriString

Optional. The URI of the spec source in case file is uploaded from an external version control system. Corresponds to the JSON property sourceUri

Returns:

  • (String)


4628
4629
4630
# File 'lib/google/apis/apihub_v1/classes.rb', line 4628

def source_uri
  @source_uri
end

#spec_typeGoogle::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues

The attribute values associated with resource. Corresponds to the JSON property specType



4633
4634
4635
# File 'lib/google/apis/apihub_v1/classes.rb', line 4633

def spec_type
  @spec_type
end

#update_timeString

Output only. The time at which the spec was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4638
4639
4640
# File 'lib/google/apis/apihub_v1/classes.rb', line 4638

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4645
4646
4647
4648
4649
4650
4651
4652
4653
4654
4655
4656
4657
4658
4659
4660
# File 'lib/google/apis/apihub_v1/classes.rb', line 4645

def update!(**args)
  @additional_spec_contents = args[:additional_spec_contents] if args.key?(:additional_spec_contents)
  @attributes = args[:attributes] if args.key?(:attributes)
  @contents = args[:contents] if args.key?(:contents)
  @create_time = args[:create_time] if args.key?(:create_time)
  @details = args[:details] if args.key?(:details)
  @display_name = args[:display_name] if args.key?(:display_name)
  @documentation = args[:documentation] if args.key?(:documentation)
  @lint_response = args[:lint_response] if args.key?(:lint_response)
  @name = args[:name] if args.key?(:name)
  @parsing_mode = args[:parsing_mode] if args.key?(:parsing_mode)
  @source_metadata = args[:source_metadata] if args.key?(:source_metadata)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @spec_type = args[:spec_type] if args.key?(:spec_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end