Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1SpecDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
SpecDetails contains the details parsed from supported spec types.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#open_api_spec_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1OpenApiSpecDetails
OpenApiSpecDetails contains the details parsed from an OpenAPI spec in addition to the fields mentioned in SpecDetails.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1SpecDetails
constructor
A new instance of GoogleCloudApihubV1SpecDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1SpecDetails
Returns a new instance of GoogleCloudApihubV1SpecDetails.
4705 4706 4707 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. The description of the spec.
Corresponds to the JSON property description
4697 4698 4699 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4697 def description @description end |
#open_api_spec_details ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1OpenApiSpecDetails
OpenApiSpecDetails contains the details parsed from an OpenAPI spec in
addition to the fields mentioned in SpecDetails.
Corresponds to the JSON property openApiSpecDetails
4703 4704 4705 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4703 def open_api_spec_details @open_api_spec_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4710 4711 4712 4713 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4710 def update!(**args) @description = args[:description] if args.key?(:description) @open_api_spec_details = args[:open_api_spec_details] if args.key?(:open_api_spec_details) end |