Class: Google::Apis::ApihubV1::GoogleCloudApihubV1SpecMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The metadata associated with a spec of the API version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1SpecMetadata

Returns a new instance of GoogleCloudApihubV1SpecMetadata.



4743
4744
4745
# File 'lib/google/apis/apihub_v1/classes.rb', line 4743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#original_create_timeString

Optional. Timestamp indicating when the spec was created at the source. Corresponds to the JSON property originalCreateTime

Returns:

  • (String)


4723
4724
4725
# File 'lib/google/apis/apihub_v1/classes.rb', line 4723

def original_create_time
  @original_create_time
end

#original_idString

Optional. The unique identifier of the spec in the system where it was originally created. Corresponds to the JSON property originalId

Returns:

  • (String)


4729
4730
4731
# File 'lib/google/apis/apihub_v1/classes.rb', line 4729

def original_id
  @original_id
end

#original_update_timeString

Required. Timestamp indicating when the spec was last updated at the source. Corresponds to the JSON property originalUpdateTime

Returns:

  • (String)


4734
4735
4736
# File 'lib/google/apis/apihub_v1/classes.rb', line 4734

def original_update_time
  @original_update_time
end

#specGoogle::Apis::ApihubV1::GoogleCloudApihubV1Spec

Represents a spec associated with an API version in the API Hub. Note that specs of various types can be uploaded, however parsing of details is supported for OpenAPI spec currently. Corresponds to the JSON property spec



4741
4742
4743
# File 'lib/google/apis/apihub_v1/classes.rb', line 4741

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4748
4749
4750
4751
4752
4753
# File 'lib/google/apis/apihub_v1/classes.rb', line 4748

def update!(**args)
  @original_create_time = args[:original_create_time] if args.key?(:original_create_time)
  @original_id = args[:original_id] if args.key?(:original_id)
  @original_update_time = args[:original_update_time] if args.key?(:original_update_time)
  @spec = args[:spec] if args.key?(:spec)
end