Class: Google::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1StringAttributeValues
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
The attribute values of data type string or JSON.
Instance Attribute Summary collapse
-
#values ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1StringAttributeValues
constructor
A new instance of GoogleCloudApihubV1StringAttributeValues.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1StringAttributeValues
Returns a new instance of GoogleCloudApihubV1StringAttributeValues.
4765 4766 4767 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#values ⇒ Array<String>
Required. The attribute values in case attribute data type is string or JSON.
Corresponds to the JSON property values
4763 4764 4765 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4763 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4770 4771 4772 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4770 def update!(**args) @values = args[:values] if args.key?(:values) end |