Class: Google::Apis::ApihubV1::GoogleCloudApihubV1ToolAnnotations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

Annotations for a Tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1ToolAnnotations

Returns a new instance of GoogleCloudApihubV1ToolAnnotations.



4898
4899
4900
# File 'lib/google/apis/apihub_v1/classes.rb', line 4898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_hintsHash<String,String>

Optional. Additional hints which may help tools and not covered in defaults. Corresponds to the JSON property additionalHints

Returns:

  • (Hash<String,String>)


4866
4867
4868
# File 'lib/google/apis/apihub_v1/classes.rb', line 4866

def additional_hints
  @additional_hints
end

#destructive_hintBoolean Also known as: destructive_hint?

Optional. Hint indicating if the tool may have destructive side effects. Corresponds to the JSON property destructiveHint

Returns:

  • (Boolean)


4871
4872
4873
# File 'lib/google/apis/apihub_v1/classes.rb', line 4871

def destructive_hint
  @destructive_hint
end

#idempotent_hintBoolean Also known as: idempotent_hint?

Optional. Hint indicating if the tool is idempotent. Corresponds to the JSON property idempotentHint

Returns:

  • (Boolean)


4877
4878
4879
# File 'lib/google/apis/apihub_v1/classes.rb', line 4877

def idempotent_hint
  @idempotent_hint
end

#open_world_hintBoolean Also known as: open_world_hint?

Optional. Hint indicating if the tool interacts with the open world (e.g., internet). Corresponds to the JSON property openWorldHint

Returns:

  • (Boolean)


4884
4885
4886
# File 'lib/google/apis/apihub_v1/classes.rb', line 4884

def open_world_hint
  @open_world_hint
end

#read_only_hintBoolean Also known as: read_only_hint?

Optional. Hint indicating if the tool is read-only. Corresponds to the JSON property readOnlyHint

Returns:

  • (Boolean)


4890
4891
4892
# File 'lib/google/apis/apihub_v1/classes.rb', line 4890

def read_only_hint
  @read_only_hint
end

#titleString

Optional. A human-readable title for the tool (if different from Tool.title). Corresponds to the JSON property title

Returns:

  • (String)


4896
4897
4898
# File 'lib/google/apis/apihub_v1/classes.rb', line 4896

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/google/apis/apihub_v1/classes.rb', line 4903

def update!(**args)
  @additional_hints = args[:additional_hints] if args.key?(:additional_hints)
  @destructive_hint = args[:destructive_hint] if args.key?(:destructive_hint)
  @idempotent_hint = args[:idempotent_hint] if args.key?(:idempotent_hint)
  @open_world_hint = args[:open_world_hint] if args.key?(:open_world_hint)
  @read_only_hint = args[:read_only_hint] if args.key?(:read_only_hint)
  @title = args[:title] if args.key?(:title)
end