Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Version
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents a version of the API resource in API hub. This is also referred to as the API version.
Instance Attribute Summary collapse
-
#accreditation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#api_operations ⇒ Array<String>
Output only.
-
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional.
-
#compliance ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#create_time ⇒ String
Output only.
-
#definitions ⇒ Array<String>
Output only.
-
#deployments ⇒ Array<String>
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#lifecycle ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#name ⇒ String
Identifier.
-
#selected_deployment ⇒ String
Optional.
-
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only.
-
#specs ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Version
constructor
A new instance of GoogleCloudApihubV1Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Version
Returns a new instance of GoogleCloudApihubV1Version.
5259 5260 5261 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accreditation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property accreditation
5164 5165 5166 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5164 def accreditation @accreditation end |
#api_operations ⇒ Array<String>
Output only. The operations contained in the API version. These operations
will be added to the version when a new spec is added or when an existing spec
is updated. Format is projects/project/locations/location/apis/api/
versions/version/operations/operation`
Corresponds to the JSON propertyapiOperations`
5172 5173 5174 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5172 def api_operations @api_operations end |
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional. The list of user defined attributes associated with the Version
resource. The key is the attribute name. It will be of the format: projects/
project/locations/location/attributes/attribute`. The value is the
attribute values associated with the resource.
Corresponds to the JSON propertyattributes`
5180 5181 5182 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5180 def attributes @attributes end |
#compliance ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property compliance
5185 5186 5187 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5185 def compliance @compliance end |
#create_time ⇒ String
Output only. The time at which the version was created.
Corresponds to the JSON property createTime
5190 5191 5192 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5190 def create_time @create_time end |
#definitions ⇒ Array<String>
Output only. The definitions contained in the API version. These definitions
will be added to the version when a new spec is added or when an existing spec
is updated. Format is projects/project/locations/location/apis/api/
versions/version/definitions/definition`
Corresponds to the JSON propertydefinitions`
5198 5199 5200 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5198 def definitions @definitions end |
#deployments ⇒ Array<String>
Optional. The deployments linked to this API version. Note: A particular API
version could be deployed to multiple deployments (for dev deployment, UAT
deployment, etc) Format is projects/project/locations/location/
deployments/deployment`
Corresponds to the JSON propertydeployments`
5206 5207 5208 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5206 def deployments @deployments end |
#description ⇒ String
Optional. The description of the version.
Corresponds to the JSON property description
5211 5212 5213 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5211 def description @description end |
#display_name ⇒ String
Required. The display name of the version.
Corresponds to the JSON property displayName
5216 5217 5218 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5216 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
5221 5222 5223 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5221 def documentation @documentation end |
#lifecycle ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property lifecycle
5226 5227 5228 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5226 def lifecycle @lifecycle end |
#name ⇒ String
Identifier. The name of the version. Format: projects/project/locations/
location/apis/api/versions/version`
Corresponds to the JSON propertyname`
5232 5233 5234 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5232 def name @name end |
#selected_deployment ⇒ String
Optional. The selected deployment for a Version resource. This can be used
when special handling is needed on client side for a particular deployment
linked to the version. Format is projects/project/locations/location/
deployments/deployment`
Corresponds to the JSON propertyselectedDeployment`
5240 5241 5242 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5240 def selected_deployment @selected_deployment end |
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only. The list of sources and metadata from the sources of the version.
Corresponds to the JSON property sourceMetadata
5245 5246 5247 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5245 def @source_metadata end |
#specs ⇒ Array<String>
Output only. The specs associated with this version. Note that an API version
can be associated with multiple specs. Format is projects/project/locations/
location/apis/api/versions/version/specs/spec`
Corresponds to the JSON propertyspecs`
5252 5253 5254 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5252 def specs @specs end |
#update_time ⇒ String
Output only. The time at which the version was last updated.
Corresponds to the JSON property updateTime
5257 5258 5259 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5257 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5264 5265 5266 5267 5268 5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5264 def update!(**args) @accreditation = args[:accreditation] if args.key?(:accreditation) @api_operations = args[:api_operations] if args.key?(:api_operations) @attributes = args[:attributes] if args.key?(:attributes) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @definitions = args[:definitions] if args.key?(:definitions) @deployments = args[:deployments] if args.key?(:deployments) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @lifecycle = args[:lifecycle] if args.key?(:lifecycle) @name = args[:name] if args.key?(:name) @selected_deployment = args[:selected_deployment] if args.key?(:selected_deployment) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @specs = args[:specs] if args.key?(:specs) @update_time = args[:update_time] if args.key?(:update_time) end |