Class: Google::Apis::ApihubV1::GoogleCloudApihubV1Version
- Inherits:
-
Object
- Object
- Google::Apis::ApihubV1::GoogleCloudApihubV1Version
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb
Overview
Represents a version of the API resource in API hub. This is also referred to as the API version.
Instance Attribute Summary collapse
-
#accreditation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#api_operations ⇒ Array<String>
Output only.
-
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional.
-
#compliance ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#create_time ⇒ String
Output only.
-
#definitions ⇒ Array<String>
Output only.
-
#deployments ⇒ Array<String>
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
-
#lifecycle ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
-
#name ⇒ String
Identifier.
-
#selected_deployment ⇒ String
Optional.
-
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only.
-
#specs ⇒ Array<String>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApihubV1Version
constructor
A new instance of GoogleCloudApihubV1Version.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApihubV1Version
Returns a new instance of GoogleCloudApihubV1Version.
5041 5042 5043 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accreditation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property accreditation
4946 4947 4948 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4946 def accreditation @accreditation end |
#api_operations ⇒ Array<String>
Output only. The operations contained in the API version. These operations
will be added to the version when a new spec is added or when an existing spec
is updated. Format is projects/project/locations/location/apis/api/
versions/version/operations/operation`
Corresponds to the JSON propertyapiOperations`
4954 4955 4956 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4954 def api_operations @api_operations end |
#attributes ⇒ Hash<String,Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues>
Optional. The list of user defined attributes associated with the Version
resource. The key is the attribute name. It will be of the format: projects/
project/locations/location/attributes/attribute`. The value is the
attribute values associated with the resource.
Corresponds to the JSON propertyattributes`
4962 4963 4964 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4962 def attributes @attributes end |
#compliance ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property compliance
4967 4968 4969 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4967 def compliance @compliance end |
#create_time ⇒ String
Output only. The time at which the version was created.
Corresponds to the JSON property createTime
4972 4973 4974 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4972 def create_time @create_time end |
#definitions ⇒ Array<String>
Output only. The definitions contained in the API version. These definitions
will be added to the version when a new spec is added or when an existing spec
is updated. Format is projects/project/locations/location/apis/api/
versions/version/definitions/definition`
Corresponds to the JSON propertydefinitions`
4980 4981 4982 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4980 def definitions @definitions end |
#deployments ⇒ Array<String>
Optional. The deployments linked to this API version. Note: A particular API
version could be deployed to multiple deployments (for dev deployment, UAT
deployment, etc) Format is projects/project/locations/location/
deployments/deployment`
Corresponds to the JSON propertydeployments`
4988 4989 4990 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4988 def deployments @deployments end |
#description ⇒ String
Optional. The description of the version.
Corresponds to the JSON property description
4993 4994 4995 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4993 def description @description end |
#display_name ⇒ String
Required. The display name of the version.
Corresponds to the JSON property displayName
4998 4999 5000 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 4998 def display_name @display_name end |
#documentation ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1Documentation
Documentation details.
Corresponds to the JSON property documentation
5003 5004 5005 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5003 def documentation @documentation end |
#lifecycle ⇒ Google::Apis::ApihubV1::GoogleCloudApihubV1AttributeValues
The attribute values associated with resource.
Corresponds to the JSON property lifecycle
5008 5009 5010 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5008 def lifecycle @lifecycle end |
#name ⇒ String
Identifier. The name of the version. Format: projects/project/locations/
location/apis/api/versions/version`
Corresponds to the JSON propertyname`
5014 5015 5016 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5014 def name @name end |
#selected_deployment ⇒ String
Optional. The selected deployment for a Version resource. This can be used
when special handling is needed on client side for a particular deployment
linked to the version. Format is projects/project/locations/location/
deployments/deployment`
Corresponds to the JSON propertyselectedDeployment`
5022 5023 5024 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5022 def selected_deployment @selected_deployment end |
#source_metadata ⇒ Array<Google::Apis::ApihubV1::GoogleCloudApihubV1SourceMetadata>
Output only. The list of sources and metadata from the sources of the version.
Corresponds to the JSON property sourceMetadata
5027 5028 5029 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5027 def @source_metadata end |
#specs ⇒ Array<String>
Output only. The specs associated with this version. Note that an API version
can be associated with multiple specs. Format is projects/project/locations/
location/apis/api/versions/version/specs/spec`
Corresponds to the JSON propertyspecs`
5034 5035 5036 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5034 def specs @specs end |
#update_time ⇒ String
Output only. The time at which the version was last updated.
Corresponds to the JSON property updateTime
5039 5040 5041 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5039 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 |
# File 'lib/google/apis/apihub_v1/classes.rb', line 5046 def update!(**args) @accreditation = args[:accreditation] if args.key?(:accreditation) @api_operations = args[:api_operations] if args.key?(:api_operations) @attributes = args[:attributes] if args.key?(:attributes) @compliance = args[:compliance] if args.key?(:compliance) @create_time = args[:create_time] if args.key?(:create_time) @definitions = args[:definitions] if args.key?(:definitions) @deployments = args[:deployments] if args.key?(:deployments) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @documentation = args[:documentation] if args.key?(:documentation) @lifecycle = args[:lifecycle] if args.key?(:lifecycle) @name = args[:name] if args.key?(:name) @selected_deployment = args[:selected_deployment] if args.key?(:selected_deployment) @source_metadata = args[:source_metadata] if args.key?(:source_metadata) @specs = args[:specs] if args.key?(:specs) @update_time = args[:update_time] if args.key?(:update_time) end |