Class: Google::Apis::ApihubV1::GoogleCloudApihubV1VersionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The metadata associated with a version of the API resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApihubV1VersionMetadata

Returns a new instance of GoogleCloudApihubV1VersionMetadata.



5105
5106
5107
# File 'lib/google/apis/apihub_v1/classes.rb', line 5105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1DeploymentMetadata>

Optional. The deployments linked to this API version. Note: A particular API version could be deployed to multiple deployments (for dev deployment, UAT deployment, etc.) Corresponds to the JSON property deployments



5075
5076
5077
# File 'lib/google/apis/apihub_v1/classes.rb', line 5075

def deployments
  @deployments
end

#original_create_timeString

Optional. Timestamp indicating when the version was created at the source. Corresponds to the JSON property originalCreateTime

Returns:

  • (String)


5080
5081
5082
# File 'lib/google/apis/apihub_v1/classes.rb', line 5080

def original_create_time
  @original_create_time
end

#original_idString

Optional. The unique identifier of the version in the system where it was originally created. Corresponds to the JSON property originalId

Returns:

  • (String)


5086
5087
5088
# File 'lib/google/apis/apihub_v1/classes.rb', line 5086

def original_id
  @original_id
end

#original_update_timeString

Required. Timestamp indicating when the version was last updated at the source. Corresponds to the JSON property originalUpdateTime

Returns:

  • (String)


5091
5092
5093
# File 'lib/google/apis/apihub_v1/classes.rb', line 5091

def original_update_time
  @original_update_time
end

#specsArray<Google::Apis::ApihubV1::GoogleCloudApihubV1SpecMetadata>

Optional. The specs associated with this version. Note that an API version can be associated with multiple specs. Corresponds to the JSON property specs



5097
5098
5099
# File 'lib/google/apis/apihub_v1/classes.rb', line 5097

def specs
  @specs
end

#versionGoogle::Apis::ApihubV1::GoogleCloudApihubV1Version

Represents a version of the API resource in API hub. This is also referred to as the API version. Corresponds to the JSON property version



5103
5104
5105
# File 'lib/google/apis/apihub_v1/classes.rb', line 5103

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5110
5111
5112
5113
5114
5115
5116
5117
# File 'lib/google/apis/apihub_v1/classes.rb', line 5110

def update!(**args)
  @deployments = args[:deployments] if args.key?(:deployments)
  @original_create_time = args[:original_create_time] if args.key?(:original_create_time)
  @original_id = args[:original_id] if args.key?(:original_id)
  @original_update_time = args[:original_update_time] if args.key?(:original_update_time)
  @specs = args[:specs] if args.key?(:specs)
  @version = args[:version] if args.key?(:version)
end