Class: Google::Apis::ApihubV1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apihub_v1/classes.rb,
lib/google/apis/apihub_v1/representations.rb,
lib/google/apis/apihub_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



5504
5505
5506
# File 'lib/google/apis/apihub_v1/classes.rb', line 5504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5489
5490
5491
# File 'lib/google/apis/apihub_v1/classes.rb', line 5489

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::ApihubV1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



5494
5495
5496
# File 'lib/google/apis/apihub_v1/classes.rb', line 5494

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5502
5503
5504
# File 'lib/google/apis/apihub_v1/classes.rb', line 5502

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5509
5510
5511
5512
5513
# File 'lib/google/apis/apihub_v1/classes.rb', line 5509

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end